# Do not build with tests by default
# Pass --with tests to rpmbuild to override
%bcond_with tests

# When --with relax_requires is specified osbuild-composer-tests
# will require osbuild-composer only by name, excluding version/release
# This is used internally during nightly pipeline testing!
%bcond_with relax_requires

# The minimum required osbuild version
%global min_osbuild_version 139

%global goipath         github.com/osbuild/osbuild-composer

Version:        135

%gometa

%global common_description %{expand:
A service for building customized OS artifacts, such as VM images and OSTree
commits, that uses osbuild under the hood. Besides building images for local
usage, it can also upload images directly to cloud.

It is compatible with composer-cli and cockpit-composer clients.
}

Name:           osbuild-composer
Release:        1%{?dist}
Summary:        An image building service based on osbuild

# osbuild-composer doesn't have support for building i686 and armv7hl images
ExcludeArch:    i686 armv7hl

# Upstream license specification: Apache-2.0
License:        Apache-2.0
URL:            %{gourl}
Source0:        %{gosource}


BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}
BuildRequires:  systemd
BuildRequires:  krb5-devel
BuildRequires:  python3-docutils
BuildRequires:  make
# Build requirements of 'theproglottis/gpgme' package
BuildRequires:  gpgme-devel
BuildRequires:  libassuan-devel
# Build requirements of 'github.com/containers/storage' package
BuildRequires:  device-mapper-devel
%if 0%{?fedora}
BuildRequires:  systemd-rpm-macros
BuildRequires:  git
# Build requirements of 'github.com/containers/storage' package
BuildRequires:  btrfs-progs-devel
# DO NOT REMOVE the BUNDLE_START and BUNDLE_END markers as they are used by 'tools/rpm_spec_add_provides_bundle.sh' to generate the Provides: bundled list
# BUNDLE_START
# BUNDLE_END
%endif

Requires: %{name}-core = %{version}-%{release}
Requires: %{name}-worker = %{version}-%{release}
Requires: systemd

Provides: weldr

%description
%{common_description}

%prep
%if 0%{?rhel}
%forgeautosetup -p1
%else
%goprep -k
%endif

%build
export GOFLAGS="-buildmode=pie"
%if 0%{?rhel}
GO_BUILD_PATH=$PWD/_build
install -m 0755 -vd $(dirname $GO_BUILD_PATH/src/%{goipath})
ln -fs $PWD $GO_BUILD_PATH/src/%{goipath}
cd $GO_BUILD_PATH/src/%{goipath}
install -m 0755 -vd _bin
export PATH=$PWD/_bin${PATH:+:$PATH}
export GOPATH=$GO_BUILD_PATH:%{gopath}
export GOFLAGS+=" -mod=vendor"
%endif

# Fedora and RHEL versions disable Go modules by default, but we want to use them.
# Unconditionally undefine the macro which disables it to use the default behavior.
%undefine gomodulesmode

# btrfs-progs-devel is not available on RHEL
%if 0%{?rhel}
GOTAGS="exclude_graphdriver_btrfs"
%endif

# Set the commit hash so that composer can report what source version
# was used to build it. This has to be set explicitly when calling rpmbuild,
# this script will not attempt to automatically discover it.
%if %{?commit:1}0
export LDFLAGS="${LDFLAGS} -X 'github.com/osbuild/osbuild-composer/internal/common.GitRev=%{commit}'"
%endif
export LDFLAGS="${LDFLAGS} -X 'github.com/osbuild/osbuild-composer/internal/common.RpmVersion=%{name}-%{?epoch:%epoch:}%{version}-%{release}.%{_arch}'"

%gobuild ${GOTAGS:+-tags=$GOTAGS} -o _bin/osbuild-composer %{goipath}/cmd/osbuild-composer
%gobuild ${GOTAGS:+-tags=$GOTAGS} -o _bin/osbuild-worker %{goipath}/cmd/osbuild-worker
%gobuild ${GOTAGS:+-tags=$GOTAGS} -o _bin/osbuild-worker-executor %{goipath}/cmd/osbuild-worker-executor
%gobuild ${GOTAGS:+-tags=$GOTAGS} -o _bin/osbuild-jobsite-manager %{goipath}/cmd/osbuild-jobsite-manager
%gobuild ${GOTAGS:+-tags=$GOTAGS} -o _bin/osbuild-jobsite-builder %{goipath}/cmd/osbuild-jobsite-builder

make man

%if %{with tests} || 0%{?rhel}

# Build test binaries with `go test -c`, so that they can take advantage of
# golang's testing package. The golang rpm macros don't support building them
# directly. Thus, do it manually, taking care to also include a build id.
#
# On Fedora, also turn off go modules and set the path to the one into which
# the golang-* packages install source code.
%if 0%{?fedora}
export GO111MODULE=off
export GOPATH=%{gobuilddir}:%{gopath}
%endif

TEST_LDFLAGS="${LDFLAGS:-} -B 0x$(od -N 20 -An -tx1 -w100 /dev/urandom | tr -d ' ')"

%if 0%{?rhel}
GOTAGS="${GOTAGS:+$GOTAGS,}rhel%{rhel}"
%endif

go test -c -tags="integration${GOTAGS:+,$GOTAGS}" -ldflags="${TEST_LDFLAGS}" -o _bin/osbuild-composer-cli-tests %{goipath}/cmd/osbuild-composer-cli-tests
go test -c -tags="integration${GOTAGS:+,$GOTAGS}" -ldflags="${TEST_LDFLAGS}" -o _bin/osbuild-dnf-json-tests %{goipath}/cmd/osbuild-dnf-json-tests
go test -c -tags="integration${GOTAGS:+,$GOTAGS}" -ldflags="${TEST_LDFLAGS}" -o _bin/osbuild-weldr-tests %{goipath}/internal/client/
go test -c -tags="integration${GOTAGS:+,$GOTAGS}" -ldflags="${TEST_LDFLAGS}" -o _bin/osbuild-image-tests %{goipath}/cmd/osbuild-image-tests
go test -c -tags="integration${GOTAGS:+,$GOTAGS}" -ldflags="${TEST_LDFLAGS}" -o _bin/osbuild-auth-tests %{goipath}/cmd/osbuild-auth-tests
go test -c -tags="integration${GOTAGS:+,$GOTAGS}" -ldflags="${TEST_LDFLAGS}" -o _bin/osbuild-koji-tests %{goipath}/cmd/osbuild-koji-tests
go test -c -tags="integration${GOTAGS:+,$GOTAGS}" -ldflags="${TEST_LDFLAGS}" -o _bin/osbuild-composer-dbjobqueue-tests %{goipath}/cmd/osbuild-composer-dbjobqueue-tests
go test -c -tags="integration${GOTAGS:+,$GOTAGS}" -ldflags="${TEST_LDFLAGS}" -o _bin/osbuild-service-maintenance-tests %{goipath}/cmd/osbuild-service-maintenance
go build -tags="integration${GOTAGS:+,$GOTAGS}" -ldflags="${TEST_LDFLAGS}" -o _bin/osbuild-mock-openid-provider %{goipath}/cmd/osbuild-mock-openid-provider

%endif

%install
install -m 0755 -vd                                                %{buildroot}%{_libexecdir}/osbuild-composer
install -m 0755 -vp _bin/osbuild-composer                          %{buildroot}%{_libexecdir}/osbuild-composer/
install -m 0755 -vp _bin/osbuild-worker                            %{buildroot}%{_libexecdir}/osbuild-composer/
install -m 0755 -vp _bin/osbuild-worker-executor                   %{buildroot}%{_libexecdir}/osbuild-composer/
install -m 0755 -vp _bin/osbuild-jobsite-manager                   %{buildroot}%{_libexecdir}/osbuild-composer/
install -m 0755 -vp _bin/osbuild-jobsite-builder                   %{buildroot}%{_libexecdir}/osbuild-composer/

# Only include repositories for the distribution and release
install -m 0755 -vd                                                %{buildroot}%{_datadir}/osbuild-composer/repositories

# CentOS also defines rhel so we check for centos first
%if 0%{?centos}

# Latest CentOS supports building all CentOS versions
%if 0%{?centos} >= 10
install -m 0644 -vp vendor/github.com/osbuild/images/data/repositories/centos-*                          %{buildroot}%{_datadir}/osbuild-composer/repositories/

%else
# All other CentOS versions support building for the same version
install -m 0644 -vp vendor/github.com/osbuild/images/data/repositories/centos-%{centos}*                 %{buildroot}%{_datadir}/osbuild-composer/repositories/
# centos-stream-* are symlinks
cp -a repositories/centos-stream-%{centos}*          %{buildroot}%{_datadir}/osbuild-composer/repositories/
%endif

%else

%if 0%{?rhel}
# RHEL 10 supports building all RHEL versions
%if 0%{?rhel} >= 10
for REPO_FILE in $(ls vendor/github.com/osbuild/images/data/repositories/rhel-* ); do
    install -m 0644 -vp ${REPO_FILE}                               %{buildroot}%{_datadir}/osbuild-composer/repositories/$(basename ${REPO_FILE})
done

# RHEL-8 auxiliary key is signed using SHA-1, which is not enabled by default on RHEL-10 and later
for REPO_FILE in $(ls repositories/rhel-8*-no-aux-key.json); do
    install -m 0644 -vp ${REPO_FILE}                               %{buildroot}%{_datadir}/osbuild-composer/repositories/$(basename ${REPO_FILE} | sed 's/-no-aux-key//g')
done

%else
# All other RHEL versions support building for the same version
for REPO_FILE in $(ls vendor/github.com/osbuild/images/data/repositories/rhel-%{rhel}* ); do
    install -m 0644 -vp ${REPO_FILE}                               %{buildroot}%{_datadir}/osbuild-composer/repositories/$(basename ${REPO_FILE})
done

# RHEL 9 supports building also for RHEL 8
%if 0%{?rhel} == 9
for REPO_FILE in $(ls vendor/github.com/osbuild/images/data/repositories/rhel-8* ); do
    install -m 0644 -vp ${REPO_FILE}                               %{buildroot}%{_datadir}/osbuild-composer/repositories/$(basename ${REPO_FILE})
done
%endif

%endif
%endif
%endif

# Fedora can build for all included fedora releases
%if 0%{?fedora}
install -m 0644 -vp vendor/github.com/osbuild/images/data/repositories/fedora-*                          %{buildroot}%{_datadir}/osbuild-composer/repositories/
%endif

install -m 0755 -vd                                                %{buildroot}%{_unitdir}
install -m 0644 -vp distribution/*.{service,socket}                %{buildroot}%{_unitdir}/

install -m 0755 -vd                                                %{buildroot}%{_sysusersdir}
install -m 0644 -vp distribution/osbuild-composer.conf             %{buildroot}%{_sysusersdir}/

install -m 0755 -vd                                                %{buildroot}%{_localstatedir}/cache/osbuild-composer/dnf-cache

install -m 0755 -vd                                                %{buildroot}%{_mandir}/man7
install -m 0644 -vp docs/*.7                                       %{buildroot}%{_mandir}/man7/

%if %{with tests} || 0%{?rhel}

install -m 0755 -vd                                                %{buildroot}%{_libexecdir}/osbuild-composer-test
install -m 0755 -vp _bin/osbuild-composer-cli-tests                %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp _bin/osbuild-weldr-tests                       %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp _bin/osbuild-dnf-json-tests                    %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp _bin/osbuild-image-tests                       %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp _bin/osbuild-auth-tests                        %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp _bin/osbuild-koji-tests                        %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp _bin/osbuild-composer-dbjobqueue-tests         %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp _bin/osbuild-service-maintenance-tests         %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp _bin/osbuild-mock-openid-provider              %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/define-compose-url.sh                    %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/provision.sh                             %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/gen-certs.sh                             %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/gen-ssh.sh                               %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/run-koji-container.sh                    %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/koji-compose.py                          %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/libvirt_test.sh                          %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/s3_test.sh                               %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/generic_s3_test.sh                       %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/generic_s3_https_test.sh                 %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/run-mock-auth-servers.sh                 %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vp tools/set-env-variables.sh                     %{buildroot}%{_libexecdir}/osbuild-composer-test/
install -m 0755 -vd                                                %{buildroot}%{_libexecdir}/tests/osbuild-composer
install -m 0755 -vp test/cases/*.sh                                %{buildroot}%{_libexecdir}/tests/osbuild-composer/

install -m 0755 -vd                                                %{buildroot}%{_libexecdir}/tests/osbuild-composer/api
install -m 0755 -vp test/cases/api/*.sh                            %{buildroot}%{_libexecdir}/tests/osbuild-composer/api/

install -m 0755 -vd                                                %{buildroot}%{_libexecdir}/tests/osbuild-composer/api/common
install -m 0755 -vp test/cases/api/common/*.sh                     %{buildroot}%{_libexecdir}/tests/osbuild-composer/api/common/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/ansible
install -m 0644 -vp test/data/ansible/*                            %{buildroot}%{_datadir}/tests/osbuild-composer/ansible/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/azure
install -m 0644 -vp test/data/azure/*                              %{buildroot}%{_datadir}/tests/osbuild-composer/azure/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/manifests
install -m 0644 -vp test/data/manifests/*                          %{buildroot}%{_datadir}/tests/osbuild-composer/manifests/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/cloud-init
install -m 0644 -vp test/data/cloud-init/*                         %{buildroot}%{_datadir}/tests/osbuild-composer/cloud-init/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/composer
install -m 0644 -vp test/data/composer/*                           %{buildroot}%{_datadir}/tests/osbuild-composer/composer/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/worker
install -m 0644 -vp test/data/worker/*                             %{buildroot}%{_datadir}/tests/osbuild-composer/worker/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/repositories
install -m 0644 -vp test/data/repositories/*                       %{buildroot}%{_datadir}/tests/osbuild-composer/repositories/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/kerberos
install -m 0644 -vp test/data/kerberos/*                           %{buildroot}%{_datadir}/tests/osbuild-composer/kerberos/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/keyring
install -m 0644 -vp test/data/keyring/id_rsa.pub                   %{buildroot}%{_datadir}/tests/osbuild-composer/keyring/
install -m 0600 -vp test/data/keyring/id_rsa                       %{buildroot}%{_datadir}/tests/osbuild-composer/keyring/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/koji
install -m 0644 -vp test/data/koji/*                               %{buildroot}%{_datadir}/tests/osbuild-composer/koji/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/x509
install -m 0644 -vp test/data/x509/*                               %{buildroot}%{_datadir}/tests/osbuild-composer/x509/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/schemas
install -m 0644 -vp pkg/jobqueue/dbjobqueue/schemas/*              %{buildroot}%{_datadir}/tests/osbuild-composer/schemas/

install -m 0755 -vd                                                %{buildroot}%{_datadir}/tests/osbuild-composer/rhel-upgrade
install -m 0644 -vp test/data/rhel-upgrade/*                       %{buildroot}%{_datadir}/tests/osbuild-composer/rhel-upgrade/

%endif

%check
export GOFLAGS="-buildmode=pie"
%if 0%{?rhel}
export GOFLAGS+=" -mod=vendor -tags=exclude_graphdriver_btrfs"
export GOPATH=$PWD/_build:%{gopath}
# cd inside GOPATH, otherwise go with GO111MODULE=off ignores vendor directory
cd $PWD/_build/src/%{goipath}
%gotest ./...
%else
%gocheck
%endif

%post
%systemd_post osbuild-composer.service osbuild-composer.socket osbuild-composer-api.socket osbuild-composer-prometheus.socket osbuild-remote-worker.socket

%preun
%systemd_preun osbuild-composer.service osbuild-composer.socket osbuild-composer-api.socket osbuild-composer-prometheus.socket osbuild-remote-worker.socket

%postun
%systemd_postun_with_restart osbuild-composer.service osbuild-composer.socket osbuild-composer-api.socket osbuild-composer-prometheus.socket osbuild-remote-worker.socket

%files
%license LICENSE
%doc README.md
%{_mandir}/man7/%{name}.7*
%{_unitdir}/osbuild-composer.service
%{_unitdir}/osbuild-composer.socket
%{_unitdir}/osbuild-composer-api.socket
%{_unitdir}/osbuild-composer-prometheus.socket
%{_unitdir}/osbuild-local-worker.socket
%{_unitdir}/osbuild-remote-worker.socket
%{_sysusersdir}/osbuild-composer.conf

%package core
Summary:    The core osbuild-composer binary
Requires:   osbuild-depsolve-dnf >= %{min_osbuild_version}
# This version needs to get bumped everytime the osbuild-depsolve-dnf json
# API changes in incompatible ways
Requires:   osbuild-dnf-json-api = 8
Provides:   %{name}-dnf-json = %{version}-%{release}
Obsoletes:  %{name}-dnf-json < %{version}-%{release}

%description core
The core osbuild-composer binary. This is suitable both for spawning in containers and by systemd.

%files core
%{_libexecdir}/osbuild-composer/osbuild-composer
%{_datadir}/osbuild-composer/

%package worker
Summary:    The worker for osbuild-composer
Requires:   systemd
Requires:   qemu-img
Requires:   osbuild >= %{min_osbuild_version}
Requires:   osbuild-ostree >= %{min_osbuild_version}
Requires:   osbuild-lvm2 >= %{min_osbuild_version}
Requires:   osbuild-luks2 >= %{min_osbuild_version}
Requires:   osbuild-depsolve-dnf >= %{min_osbuild_version}
Provides:   %{name}-dnf-json = %{version}-%{release}
Obsoletes:  %{name}-dnf-json < %{version}-%{release}

%description worker
The worker for osbuild-composer

%files worker
%{_libexecdir}/osbuild-composer/osbuild-worker
%{_libexecdir}/osbuild-composer/osbuild-worker-executor
%{_libexecdir}/osbuild-composer/osbuild-jobsite-manager
%{_libexecdir}/osbuild-composer/osbuild-jobsite-builder
%{_unitdir}/osbuild-worker@.service
%{_unitdir}/osbuild-remote-worker@.service

%post worker
%systemd_post osbuild-worker@.service osbuild-remote-worker@.service

%preun worker
# systemd_preun uses systemctl disable --now which doesn't work well with template services.
# See https://github.com/systemd/systemd/issues/15620
# The following lines mimicks its behaviour by running two commands.
# The scriptlet is supposed to run only when the package is being removed.
if [ $1 -eq 0 ] && [ -d /run/systemd/system ]; then
    # disable and stop all the worker services
    systemctl --no-reload disable osbuild-worker@.service osbuild-remote-worker@.service
    systemctl stop "osbuild-worker@*.service" "osbuild-remote-worker@*.service"
fi

%postun worker
# restart all the worker services
%systemd_postun_with_restart "osbuild-worker@*.service" "osbuild-remote-worker@*.service"

%if %{with tests} || 0%{?rhel}

%package tests
Summary:    Integration tests
%if %{with relax_requires}
Requires:   %{name}
%else
Requires:   %{name} = %{version}-%{release}
%endif
Requires:   composer-cli
Requires:   createrepo_c
Requires:   xorriso
Requires:   qemu-kvm-core
Requires:   systemd-container
Requires:   jq
Requires:   unzip
Requires:   container-selinux
Requires:   dnsmasq
Requires:   krb5-workstation
Requires:   podman
Requires:   python3
Requires:   sssd-krb5
Requires:   libvirt-client libvirt-daemon
Requires:   libvirt-daemon-config-network
Requires:   libvirt-daemon-config-nwfilter
Requires:   libvirt-daemon-driver-interface
Requires:   libvirt-daemon-driver-network
Requires:   libvirt-daemon-driver-nodedev
Requires:   libvirt-daemon-driver-nwfilter
Requires:   libvirt-daemon-driver-qemu
Requires:   libvirt-daemon-driver-secret
Requires:   libvirt-daemon-driver-storage
Requires:   libvirt-daemon-driver-storage-disk
Requires:   libvirt-daemon-kvm
Requires:   qemu-img
Requires:   qemu-kvm
Requires:   rpmdevtools
Requires:   virt-install
Requires:   expect
Requires:   python3-lxml
Requires:   httpd
Requires:   mod_ssl
Requires:   openssl
Requires:   firewalld
# podman-plugins has been deprecated since podman version 5.0.0,
# which is in Fedora 40+ and in c10s / el10
%if (0%{?rhel} && 0%{?rhel} < 10) || (0%{?fedora} && 0%{?fedora} < 40)
Requires:   podman-plugins
%endif
Requires:   dnf-plugins-core
Requires:   skopeo
Requires:   make
Requires:   python3-pip
%if 0%{?fedora}
# koji and ansible are not in RHEL repositories. Depending on them breaks RHEL
# gating (see OSCI-1541). The test script must enable EPEL and install those
# packages manually.
Requires:   koji
Requires:   ansible
%endif
%ifarch %{arm}
Requires:   edk2-aarch64
%endif

%description tests
Integration tests to be run on a pristine-dedicated system to test the osbuild-composer package.

%files tests
%{_libexecdir}/osbuild-composer-test/
%{_libexecdir}/tests/osbuild-composer/
%{_datadir}/tests/osbuild-composer/

%endif

%changelog
* Wed Mar 05 2025 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 135-1
- New upstream release

* Mon Feb 24 2025 Tomáš Hozza <thozza@redhat.com> - 134-1
- New upstream release
- Resolves: RHEL-80161

* Thu Feb 13 2025 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 132-1
- New upstream release

* Wed Feb 05 2025 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 131-1
- New upstream release

* Wed Jan 08 2025 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 128-1
- New upstream release

* Wed Dec 11 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 127-1
- New upstream release

* Wed Nov 27 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 126-1
- New upstream release

* Thu Nov 14 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 125-1
- New upstream release

* Fri Nov 01 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 124-1
- New upstream release

* Tue Oct 29 2024 Troy Dawson <tdawson@redhat.com> - 123-2
- Bump release for October 2024 mass rebuild:
  Resolves: RHEL-64018

* Wed Oct 16 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 123-1
- New upstream release

* Fri Aug 23 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 118-1
- New upstream release

* Wed Aug 21 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 117-1
- New upstream release

* Thu Aug 15 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 116-1
- New upstream release

* Wed Aug 07 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 115-1
- New upstream release

* Wed Jul 24 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 114-1
- New upstream release

* Tue Jul 23 2024 Tomáš Hozza <thozza@redhat.com> - 113-2
- Rebuild for test case fix

* Fri Jul 12 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 113-1
- New upstream release

* Mon Jun 24 2024 Troy Dawson <tdawson@redhat.com> - 109-2
- Bump release for June 2024 mass rebuild

* Tue Jun 04 2024 Tomáš Hozza <thozza@redhat.com> - 109-1
- New upstream release + bachport upstream fix to make tests pass on el10

* Fri May 31 2024 Tomáš Hozza <thozza@redhat.com> - 108-2
- Bachport upstream fixes to make tests pass

* Fri May 17 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 108-1
- New upstream release

* Wed May 01 2024 imagebuilder-bot <imagebuilder-bots+imagebuilder-bot@redhat.com> - 106-1
- New upstream release

* Sun Feb 11 2024 Maxwell G <maxwell@gtmx.me> - 100-2
- Rebuild for golang 1.22.0

* Wed Feb 07 2024 Packit <hello@packit.dev> - 100-1
Changes with 100
----------------
  * CI: update terraform SHA (#3919)
    * Author: Jakub Rusz, Reviewers: Achilleas Koutsou
  * Cloud API: Add Fedora IoT bootable container (#3916)
    * Author: Achilleas Koutsou, Reviewers: Ondřej Budai
  * DEPLOYING/HACKING.md: Consistently use inline refs (#3930)
    * Author: Simon Steinbeiß, Reviewers: Tomáš Hozza
  * HACKING/DEPLOYING.md: Markdown syntax fixes (#3929)
    * Author: Simon Steinbeiß, Reviewers: Ondřej Budai
  * Update osbuild/images to v0.35.0 (#3932)
    * Author: Tomáš Hozza, Reviewers: Sanne Raymaekers
  * Use dot to separate distro major and minor version and replace distro registry with factory (#3887)
    * Author: Tomáš Hozza, Reviewers: Achilleas Koutsou
  * build(deps): bump actions/setup-go from 4 to 5 (#3842)
    * Author: dependabot[bot], Reviewers: Tomáš Hozza
  * build(deps): bump actions/upload-artifact from 3 to 4 (#3855)
    * Author: dependabot[bot], Reviewers: Tomáš Hozza
  * build(deps): bump the go-deps group with 10 updates (#3923)
    * Author: dependabot[bot], Reviewers: Tomáš Hozza
  * pkg/jobqueue: fix worker status update query (#3922)
    * Author: Sanne Raymaekers, Reviewers: Diaa Sami, Gianluca Zuccarelli
  * templates/dashboards: add community stage service to orgs (#3931)
    * Author: Sanne Raymaekers, Reviewers: Simon Steinbeiß
  * templates/packer: deal with unbound variables (#3920)
    * Author: Sanne Raymaekers, Reviewers: Simon Steinbeiß
  * test: remove workarounds for fixed bugs (#3933)
    * Author: Xiaofeng Wang, Reviewers: Jakub Rusz
  * tests/CI: Add RHEL 9.3 and 8.9 GA to pipeline (#3892)
    * Author: tkoscieln, Reviewers: Alexander Todorov, Jakub Rusz

— Somewhere on the Internet, 2024-02-07


* Wed Jan 24 2024 Packit <hello@packit.dev> - 99-1
Changes with 99
----------------
  * Add a tool script to help check for unused runners (#3614)
    * Author: Brian C. Lane, Reviewers: Tomáš Hozza
  * Bump azure (#3853)
    * Author: Sanne Raymaekers, Reviewers: Ondřej Budai
  * COMPOSER-2096: Add blueprint support to cloudapi & local access to cloudapi service (#3757)
    * Author: Brian C. Lane, Reviewers: Sanne Raymaekers
  * Fedora worker images (#3902)
    * Author: Sanne Raymaekers, Reviewers: Achilleas Koutsou, Tomáš Hozza
  * Invert wrong boolean condition in filesystem test (#3889)
    * Author: Alexander Todorov, Reviewers: Tomáš Hozza
  * Remove oscap.sh firewalld rules workaround (#3905)
    * Author: Alexander Todorov, Reviewers: Tomáš Hozza
  * Update test runners to Fedora 39 (#3820)
    * Author: Alexander Todorov, Reviewers: Achilleas Koutsou, Michael Vogt, Ondřej Budai, Tomáš Hozza
  * edge: add iot-simplified-installer image type (#3900)
    * Author: djach7, Reviewers: Achilleas Koutsou
  * image-info: update for new "partition" option in mounts.Mount (#3883)
    * Author: Michael Vogt, Reviewers: Achilleas Koutsou, Tomáš Hozza
  * tools/build-rpms: fix getting the osbuild commit from Schutzfile (#3897)
    * Author: Sanne Raymaekers, Reviewers: Achilleas Koutsou, Simon Steinbeiß
  * tools/fedora-worker-packer: fix packer only/except (#3910)
    * Author: Sanne Raymaekers, Reviewers: Tomáš Hozza

— Somewhere on the Internet, 2024-01-24


* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 98-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Jan 10 2024 Packit <hello@packit.dev> - 98-1
Changes with 98
----------------
  * Update snapshots to 20240101 (#3876)
    * Author: SchutzBot, Reviewers: Jakub Rusz
  * build(deps): bump the go-deps group with 5 updates (#3877)
    * Author: dependabot[bot], Reviewers: Ondřej Budai
  * schutzbot: add my "mvogt" SSH key (#3882)
    * Author: Michael Vogt, Reviewers: Achilleas Koutsou

— Somewhere on the Internet, 2024-01-10


* Wed Dec 13 2023 Packit <hello@packit.dev> - 96-1
Changes with 96
----------------
  * .gitlab-ci.yml: upgade neetle early to workaround RHEL-17890 (#3847)
    * Author: Alexander Todorov, Reviewers: Tomáš Hozza
  * README: remove IRC in favour of matrix channel (#3844)
    * Author: Sanne Raymaekers, Reviewers: Achilleas Koutsou, Simon de Vlieger
  * Worker status heartbeat (#3766)
    * Author: Sanne Raymaekers, Reviewers: Nobody
  * build(deps): bump actions/github-script from 6 to 7 (#3806)
    * Author: dependabot[bot], Reviewers: Nobody
  * build(deps): bump the go-deps group with 5 updates (#3837)
    * Author: dependabot[bot], Reviewers: Achilleas Koutsou
  * cloudapi/v2: fix verbiage of customizations (#3839)
    * Author: Sanne Raymaekers, Reviewers: Diaa Sami
  * rpmbuild: add fedora-40 (#3838)
    * Author: Jakub Rusz, Reviewers: Alexander Todorov
  * test: fix ansible playbook conditional statements error (#3845)
    * Author: Xiaofeng Wang, Reviewers: Achilleas Koutsou
  * test: remove persistent log checking on minimal raw test (#3836)
    * Author: Xiaofeng Wang, Reviewers: Achilleas Koutsou

— Somewhere on the Internet, 2023-12-13


* Wed Nov 29 2023 Packit <hello@packit.dev> - 95-1
Changes with 95
----------------
  * :lock: Update `filesystem.sh` test case to reflect update mountpoint policy (#3796)
    * Author: Tomáš Hozza, Reviewers: Brian C. Lane
  * Cloud API: Support selecting multiple upload targets and add Pulp OSTree uploads (#3744)
    * Author: Achilleas Koutsou, Reviewers: Sanne Raymaekers
  * Fix rhel9 oscap test (#3816)
    * Author: Gianluca Zuccarelli, Reviewers: Alexander Todorov, Jakub Rusz
  * Revert "containers/osbuild-composer: wait for fluentd in entrypoint" (#3819)
    * Author: Diaa Sami, Reviewers: Sanne Raymaekers
  * Switch testing to RHEL-8.10 and RHEL-9.4 nightly (#3775)
    * Author: Jakub Rusz, Reviewers: Alexander Todorov
  * composer: use logrus hook instead of k8s sidecar for splunk log forwa… (#3795)
    * Author: Diaa Sami, Reviewers: Sanne Raymaekers
  * deps: update images to v0.18.0 (#3635)
    * Author: Achilleas Koutsou, Reviewers: Simon de Vlieger
  * pkg/splunk_logger: make it a module that can be imported seprately (#3799)
    * Author: Diaa Sami, Reviewers: Achilleas Koutsou
  * schutzbot/terraform: aws instance types rework (#3791)
    * Author: Sanne Raymaekers, Reviewers: Achilleas Koutsou
  * test/cases/ubi-wsl: query Windows VM ip address via vm show (#3800)
    * Author: Sanne Raymaekers, Reviewers: Jakub Rusz

— Somewhere on the Internet, 2023-11-29


* Wed Nov 15 2023 Packit <hello@packit.dev> - 94-1
Changes with 94
----------------
  * .github: update apt metadata before installing deps (#3788)
    * Author: Sanne Raymaekers, Reviewers: Ondřej Budai, Simon de Vlieger, Tomáš Hozza
  * Add pkg splunk_logging (#3750)
    * Author: Diaa Sami, Reviewers: Ondřej Budai, Sanne Raymaekers
  * Added hyper_v_generation metadata to the instance used by CIV. (#3769)
    * Author: Nicolás M., Reviewers: Alexander Todorov, Jakub Rusz, Tomáš Hozza
  * Blueprints: Fix TOML filesystem `minsize` keyword (#3783)
    * Author: Gianluca Zuccarelli, Reviewers: Achilleas Koutsou, Tomáš Hozza
  * Generate RHEL-94 and RHEL-810 manifests + update (#3778)
    * Author: Jakub Rusz, Reviewers: Alexander Todorov
  * build(deps): bump the go-deps group with 10 updates (#3794)
    * Author: dependabot[bot], Reviewers: Tomáš Hozza
  * schutzbot/terraform: update rhel-9.2 aarch64 image (#3789)
    * Author: Sanne Raymaekers, Reviewers: Simon Steinbeiß
  * store: Fix RepoConfig (#3764)
    * Author: Brian C. Lane, Reviewers: Ondřej Budai
  * tools/provision: disable tracing before manipulating OCI secrets (#3784)
    * Author: Sanne Raymaekers, Reviewers: Brian C. Lane

— Somewhere on the Internet, 2023-11-15


* Wed Nov 01 2023 Packit <hello@packit.dev> - 93-1
Changes with 93
----------------
  * :package: Packit configuration enhancements (#3768)
    * Author: Tomáš Hozza, Reviewers: Achilleas Koutsou, Ondřej Budai, Simon Steinbeiß
  * Add partitioning mode support to cloudapi and weldr api (#3723)
    * Author: Brian C. Lane, Reviewers: Ondřej Budai
  * Add support for uploading an ostree commit to Pulp (#3636)
    * Author: Achilleas Koutsou, Reviewers: Nobody
  * Build rpms on RHEL-8.10 and RHEL-9.4 (#3772)
    * Author: Jakub Rusz, Reviewers: Alexander Todorov
  * Post `osbuild/images` split autumn cleanup :broom: (#3754)
    * Author: Tomáš Hozza, Reviewers: Achilleas Koutsou, Simon de Vlieger
  * test/README: run go tests when updating images (#3763)
    * Author: Achilleas Koutsou, Reviewers: Tomáš Hozza, djach7

— Somewhere on the Internet, 2023-11-01


* Tue Oct 24 2023 Packit <hello@packit.dev> - 88.2-1
Changes with 88.2
-----------------
  * deps: update osbuild/images to v0.3.0-r9.3.3 (#3756)

Contributions from: Achilleas Koutsou

— Berlin, 2023-10-24

* Wed Oct 18 2023 Packit <hello@packit.dev> - 92-1
Changes with 92
----------------
  * Enable Azure testing on HyperV Gen2 (#3679)
    * Author: Alexander Todorov, Reviewers: Jakub Rusz, Tomáš Hozza
  * Internal: delete unused `common.VersionLessThan()` (#3729)
    * Author: Tomáš Hozza, Reviewers: Ondřej Budai
  * Small fixes for Koji data consolidation PR#3599 (#3719)
    * Author: Tomáš Hozza, Reviewers: Achilleas Koutsou, Simon de Vlieger
  * Support F40, EL8.10, EL9.4, ppc64le and s390x on Fedora (#3740)
    * Author: Tomáš Hozza, Reviewers: Achilleas Koutsou, Simon de Vlieger
  * build(deps): bump the go-deps group with 2 updates (#3748)
    * Author: dependabot[bot], Reviewers: Tomáš Hozza
  * build(deps): bump the go-deps group with 7 updates (#3737)
    * Author: dependabot[bot], Reviewers: Tomáš Hozza
  * cloudapi/v2: add all existing customizations to openapi spec (#3716)
    * Author: Sanne Raymaekers, Reviewers: Brian C. Lane
  * cloudapi: Move Services to an actual struct (#3735)
    * Author: Brian C. Lane, Reviewers: Sanne Raymaekers
  * fix ostree vmdk test timeout (#3724)
    * Author: He Yi, Reviewers: Xiaofeng Wang
  * go.mod: update images to 0.11 (#3722)
    * Author: Ondřej Budai, Reviewers: Brian C. Lane

— Somewhere on the Internet, 2023-10-18


* Wed Oct 04 2023 Packit <hello@packit.dev> - 91-1
Changes with 91
----------------
  * Add checksums to mock data (#3683)
    * Author: Brian C. Lane, Reviewers: Achilleas Koutsou
  * Consolidation & extension of information imported to Koji builds (#3659)
    * Author: Tomáš Hozza, Reviewers: Achilleas Koutsou, Simon de Vlieger
  * Revert "Add softlockup_all_cpu_backtrace=1 boot argument" (#3680)
    * Author: Alexander Todorov, Reviewers: Tomáš Hozza
  * build(deps): bump actions/checkout from 3 to 4 (#3678)
    * Author: dependabot[bot], Reviewers: Tomáš Hozza
  * build(deps): bump the go-deps group with 1 update (#3704)
    * Author: dependabot[bot], Reviewers: Sanne Raymaekers
  * build(deps): bump the go-deps group with 6 updates (#3703)
    * Author: dependabot[bot], Reviewers: Nobody
  * cloudapi/v2: log manifest generation errors as a warning (#3709)
    * Author: Sanne Raymaekers, Reviewers: Gianluca Zuccarelli
  * dashboard: worker api dashboard (#3712)
    * Author: Sanne Raymaekers, Reviewers: Gianluca Zuccarelli
  * dashboards: fix composer dash request rate errors (#3710)
    * Author: Sanne Raymaekers, Reviewers: Gianluca Zuccarelli
  * lint: fix memory aliasing (#3711)
    * Author: Brian C. Lane, Reviewers: Achilleas Koutsou
  * templates/compose: add startingDeadlineSeconds to maintenance job (#3698)
    * Author: Sanne Raymaekers, Reviewers: Tomáš Hozza
  * templates/composer: parameterise maintenance job cpu req/limit (#3697)
    * Author: Sanne Raymaekers, Reviewers: Ondřej Budai
  * templates/packer: configure oracle cloud credentials on startup (#3694)
    * Author: Sanne Raymaekers, Reviewers: Gianluca Zuccarelli
  * test: remove fdo package workaround from PR#3690 (#3713)
    * Author: Xiaofeng Wang, Reviewers: Brian C. Lane
  * tools/appsre-ansible/rpmbuild: retry all tasks (#3701)
    * Author: Sanne Raymaekers, Reviewers: Diaa Sami

— Somewhere on the Internet, 2023-10-04


* Wed Sep 20 2023 Packit <hello@packit.dev> - 90-1
Changes with 90
----------------
  * Actions: add workflow for marking and closing stale issues and PRs (#3676)
    * Author: Tomáš Hozza, Reviewers: Achilleas Koutsou
  * Add test case for iot-qcow2-image (#3668)
    * Author: He Yi, Reviewers: Xiaofeng Wang
  * OpenSCAP cloudapi tailoring (#3617)
    * Author: Gianluca Zuccarelli, Reviewers: Tomáš Hozza
  * oci object storage target (#3675)
    * Author: Sanne Raymaekers, Reviewers: Gianluca Zuccarelli
  * test/cases/ubi-wsl: set --os-type when creating vm (#3686)
    * Author: Sanne Raymaekers, Reviewers: Tomáš Hozza
  * test: remove workaround for bug BZ#2234390 (#3684)
    * Author: Xiaofeng Wang, Reviewers: Achilleas Koutsou, Brian C. Lane
  * test: workaround fdo package issue (#3690)
    * Author: Xiaofeng Wang, Reviewers: Achilleas Koutsou

— Somewhere on the Internet, 2023-09-20


* Wed Sep 06 2023 Packit <hello@packit.dev> - 89-1
Changes with 89
----------------
  * Handle panics in the osbuild job & fix panic when OCI authentication fails (#3666)
  * Oci test (#3629)
  * Tests: Add softlockup_all_cpu_backtrace=1 boot argument (#3656)
  * Tests: Remove deprecated --os-type cli argument (#3643)
  * build(deps): bump the go-deps group with 2 updates (#3661)
  * cloudapi/v2: expose wsl image type (#3660)
  * test/cases/ubi-wsl: fix waiting for a valid ipv4 (#3670)
  * test/cases/ubi-wsl: public ip fixes (#3653)
  * test: add workaround for bug BZ#2234390 (#3663)
  * test: fix "Waiter SnapshotImported failed: Max attempts exceeded" (#3662)

Contributions from: Alexander Todorov, Ondřej Budai, Sanne Raymaekers, Xiaofeng Wang, dependabot[bot]

— Somewhere on the Internet, 2023-09-06


* Thu Aug 24 2023 Packit <hello@packit.dev> - 88-1
Changes with 88
----------------
  * COMPOSER-2016: blueprint: make Convert respect nils (#3612)
  * Update rhel ga runners (#3596)
  * Use newer RHEL 8.9 & 9.3 images for testing (#3603)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.318 to 1.44.322 (#3620)
  * build(deps): bump github.com/openshift-online/ocm-sdk-go from 0.1.315 to 0.1.362 (#3627)
  * cloudapi: Add ability to skip uploading and save image locally (#3585)
  * dashboards/worker: default to showing the past 6 hours (#3651)
  * dependabot: group go package updates (#3642)
  * deps: update osbuild/images to 9548bf0d0140 (#3606)
  * deps: update osbuild/images to v0.3.0 (#3634)
  * go.mod: bump osbuild/images to c2aa82cc9a86 (#3640)
  * internal/cloud/gcp/compute: Add SEV_SNP_CAPABLE Guest OS Feature (#3579)
  * schutzbot: unregister test hosts (#3630)
  * test/cases/ubi-wsl: double ssh timeout (#3624)
  * test: add workaround for bug 2230537 and 2229722 (#3615)
  * test: run greenboot rollback test on ostree.sh, ostree-ami-image.sh and ostree-vsphere.sh (#3618)
  * test: update edge-ami test to support aarch64 (#3613)
  * test: wait for ami image avaiable to use before tag creation (#3619)

Contributions from: Achilleas Koutsou, Alexander Todorov, Brian C. Lane, Ondřej Budai, Sanne Raymaekers, Timothée Ravier, Tomáš Hozza, Xiaofeng Wang, dependabot[bot]

— Somewhere on the Internet, 2023-08-24


* Wed Aug 09 2023 Packit <hello@packit.dev> - 87-1
Changes with 87
----------------
  * Koji: expose image metadata in build extra metadata, including boot mode (#3599)
  * Main cloud size (#3597)
  * Update snapshots to 20230801 (#3592)
  * deps: update osbuild/images to 157e798fdf8d (#3593)
  * test/cases/api: add check for subscription-manager facts (#3257)
  * test: Fix Fedora 39 snapshot urls in test repo (#3574)
  * tests: Add a check for valid snapshot urls (#3572)

Contributions from: Achilleas Koutsou, Brian C. Lane, Jakub Rusz, Sanne Raymaekers, Tomáš Hozza, Xiaofeng Wang, schutzbot, yih

— Somewhere on the Internet, 2023-08-09


* Wed Jul 26 2023 Packit <hello@packit.dev> - 86-1
Changes with 86
----------------
  * Openapi revision (#3286)
  * Start collecting logs from virt-install (#3557)
  * Ubi wsl (#3473)
  * Update osbuild/images (#3565)
  * ci: fix the gitlab trigger (#3568)
  * packer: Move to Fedora 38 and use cheaper GP3 volumes (#3554)
  * spec: require osbuild >= 89 (#3524)
  * test/README: describe vendoring modified images repo (#3564)
  * tools: Set a+x on rpm_spec_vendor2provides (#3562)
  * tools: replace spec Provides generator (#3560)

Contributions from: Achilleas Koutsou, Alexander Todorov, Brian C. Lane, Diaa Sami, Mario Cattamo, Ondřej Budai, Sanne Raymaekers, Simon de Vlieger, Xiaofeng Wang

— Somewhere on the Internet, 2023-07-26


* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 85-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Wed Jul 12 2023 Packit <hello@packit.dev> - 85-1
Changes with 85
----------------
  * Allow any hashing algorithm in osbuild stage inputs (#3514)
  * COMPOSER-1959: Test on 8.9 and 9.3 nightly (#3422)
  * Deprecated mas sso (#3531)
  * Enable CI for Fedora 38 & a few cleanups (#3481)
  * Fix ISO building on F39 (#3523)
  * Fix for possibly undefined variable in CI script (#3549)
  * Introduce test conditions for AWS & Azure (#3493)
  * Packit/copr: Remove EPEL builds in favor of RHEL ones (#3507)
  * Remove Juan from the list of QE associates (#3550)
  * Remove redundant script in upgrade8to9 test (#3508)
  * Set the tenant in the request context, reuse it for the status and request duration metrics (#3510)
  * Update Cloud API with new manifest generation process (#3482)
  * Update manifests (#3494)
  * Update snapshots to 20230701 (#3540)
  * Upgrade 8to9 upgrade test for 9.3 (#3505)
  * cloudapi/v2: cleanup rebase leftovers (#3552)
  * cloudapi: openscap integration (#3522)
  * containers/osbuild-composer: add prometheus port parameter (#3497)
  * distro/rhel8: fix Azure EAP7 RHUI image definition (#3502)
  * jsondb: improve performance of list operation (#3504)
  * reorder middlewares in worker and cloud apis (#3534)
  * templates/dasbhoards: rework composer dashboard (#3538)
  * test/repos: use EUS CDN repos for RHEL 8.4 / 8.6 / 9.0 (#3467)
  * test: Four fixes for RHEL for Edge tests (#3532)
  * test: Remove rebase test shell script (#3530)
  * test: Some enhancements to make test stable (#3495)

Contributions from: Achilleas Koutsou, Alexander Todorov, Diaa Sami, Eng Zer Jun, Gianluca Zuccarelli, Ondřej Budai, Sanne Raymaekers, Simon de Vlieger, Tomáš Hozza, Xiaofeng Wang, dependabot[bot], schutzbot

— Somewhere on the Internet, 2023-07-12


* Wed Jun 14 2023 Packit <hello@packit.dev> - 84-1
Changes with 84
----------------
  * Add the 'edge-ami' image type based on edge-raw-image (#3429)
  * CI: Move RHEL for Edge CI into osbuild/rhel-edge-ci repo (#3460)
  * Cleanup of Fedora cloud images (#3480)
  * Finalise interface between composer and image definitions (#3444)
  * Update snapshots to 20230522 (#3451)
  * build(deps): bump google.golang.org/api from 0.123.0 to 0.126.0 (#3485)
  * cloudapi: add vsphere-ova type (#3474)
  * fedora: f36 went EOL (#3445)
  * internal/cloudapi: new prometheus listener (#3430)
  * internal/osbuild: yum repos ssl verify (#3419)
  * osbuild: Add validation error logging (#3483)
  * templates/composer:  parametrise replicas and tweak cpu requests/limits (#3472)

Contributions from: Achilleas Koutsou, Brian C. Lane, Diaa Sami, Gianluca Zuccarelli, Irene Diez, Ondřej Budai, Sanne Raymaekers, Simon de Vlieger, Tomáš Hozza, Xiaofeng Wang, dependabot[bot], jabia99, schutzbot

— Somewhere on the Internet, 2023-06-14


* Wed May 31 2023 Packit <hello@packit.dev> - 83-1
Changes with 83
----------------
  * Add support for VMware ovf image type (#3371)
  * Add tests for blueprint package name globs and fix blueprint freeze with globs (#3425)
  * CI: update centos-stream-8 images and snapshots (#3466)
  * Dockerfile*: update to ubi9 and chown the files when copying (#3443)
  * Fedora/iot-raw-image: support custom files and directories in `/etc` (+ services customization) (#3303)
  * Fixes for the koji integration (#3399)
  * Revert the hybrid boot mode changes on RHEL (RHUI) EC2 images prior to 8.9 / 9.3 (#3455)
  * Support hybrid boot mode on x86_64 AMI images and set the AMI boot mode on image registration (#3446)
  * build(deps): bump cloud.google.com/go/compute from 1.10.0 to 1.19.3 (#3442)
  * build(deps): bump cloud.google.com/go/storage from 1.27.0 to 1.30.1 (#3428)
  * build(deps): bump github.com/docker/distribution from 2.8.1+incompatible to 2.8.2+incompatible (#3437)
  * build(deps): bump github.com/labstack/echo/v4 from 4.10.0 to 4.10.2 (#3454)
  * build(deps): bump github.com/stretchr/testify from 1.8.2 to 1.8.3 (#3457)
  * build(deps): bump google.golang.org/api from 0.122.0 to 0.123.0 (#3453)
  * internal/GCP: remove all remaining uses of `cloudbuild` (#3450)
  * iot: add fedora-release-iot to iot-installer (#3441)

Contributions from: Alexander Todorov, Brian C. Lane, Jakub Rusz, Ondřej Budai, Paul Whalen, Sanne Raymaekers, Tomáš Hozza, dependabot[bot]

— Somewhere on the Internet, 2023-05-31


* Wed May 17 2023 Packit <hello@packit.dev> - 82-1
Changes with 82
----------------
  * Adjust packer build to work with the amazon plugin 1.2.3 (#3402)
  * Disable firewalld for RHEL 8 Azure EAP (#3421)
  * Update terraform SHA (#3420)
  * cloudapi: custom repos add missing fields (#3418)
  * internal/manifest: install rhc-worker-playbook when using rhc (#3432)

Contributions from: Achilleas Koutsou, Gianluca Zuccarelli, Jakub Rusz, Ondřej Budai, Sanne Raymaekers, dependabot[bot], jabia99

— Somewhere on the Internet, 2023-05-17


* Wed Apr 19 2023 Packit <hello@packit.dev> - 80-1
Changes with 80
----------------
  * COMPOSER-1936: Enable regression-insecure-repo test for nightly CI pipeline (#3380)
  * COMPOSER-1943: Fix failure in cross-distro.sh (#3379)
  * Save manifest lists when pulling containers (#3336)
  * Simplify packit config (#3339)
  * Test/fix cs9 edge-simplified-installer test failure (#3382)
  * build(deps): bump github.com/docker/docker from 20.10.17+incompatible to 20.10.24+incompatible (#3376)
  * cloudapi/v2: expose repo metadata verification (#3387)
  * dbjobqueue: Make dequeuing atomic (#3389)
  * internal/worker: log dequeue failures (#3369)
  * rpi firmware copy (#3391)

Contributions from: Achilleas Koutsou, Alexander Todorov, Gianluca Zuccarelli, Jiri Popelka, Ondřej Budai, Sanne Raymaekers, Simon de Vlieger, dependabot[bot], yih

— Somewhere on the Internet, 2023-04-19


* Wed Apr 05 2023 Packit <hello@packit.dev> - 79-1
Changes with 79
----------------
  * Add Butane test and Ignition logs (#3223)
  * Add tags to CIV instances (#3343)
  * COMPOSER-1936: Use check_gpg=True during testing (#3353)
  * New image type: Azure EAP for RHEL 8.6+ (no RHEL 9). (#3288)
  * build(deps): bump github.com/opencontainers/runc from 1.1.3 to 1.1.5 (#3365)
  * containers/osbuild-composer: wait for fluentd in entrypoint (#3357)
  * distro/rhel: add payload repos to os package set (#3329)
  * internal/boot: boot VMWare VMs with EFI and SCSI (#3351)
  * packit: build RPMs also for EPEL 9 and RHEL (#3359)
  * per-distro rpmmd cache directory (#3317)
  * upload/azure: modernize & do not upload zeroed pages (#3367)
  * weldr+distro: allow to send Manifest warnings on ComposeReply (#3319)

Contributions from: Achilleas Koutsou, Alexander Todorov, Brian C. Lane, Diaa Sami, Irene Diez, Jakub Rusz, Juan Abia, Mario Cattamo, Ondřej Budai, Sanne Raymaekers, Tomáš Hozza, dependabot[bot]

— Somewhere on the Internet, 2023-04-05


* Wed Mar 22 2023 Packit <hello@packit.dev> - 78-1
Changes with 78
----------------
  * Change civ repo name (#3340)
  * File resolver job (#3254)
  * Introduce jobtype variable in worker dashboard (#3262)
  * Test/ostree: add sysroot permission test (#3325)
  * build(deps): bump actions/setup-go from 3 to 4 (#3337)
  * distro/fedora: add support for Fedora 39 (#3324)
  * distro: remove duplicate version checks for fonts (#3280)
  * image-installer: switch payload to minimal-rpm (#3249)
  * iot-raw-image: partitioning changes (#3246)
  * simplified-installer: enable isolinux (#3327)
  * test/vmware: boot VMs with EFI and use SCSI as a disk controller (#3330)
  * tests/ostree: Change centos-8 BOOT_LOCATION to a working boot.iso (#3338)

Contributions from: Antonio Murdaca, Gianluca Zuccarelli, Jakub Rusz, Juan Abia, Sanne Raymaekers, Simon de Vlieger, dependabot[bot], yih

— Somewhere on the Internet, 2023-03-22


* Wed Mar 08 2023 Packit <hello@packit.dev> - 77-1
Changes with 77
----------------
  * Add open-vm-tools to Fedora VMDK image default package set (#3300)
  * Update deprecated io/ioutil functions and go:build tags (#3323)
  * Update rpmrepo snapshots to 20230223 (including necessary fixes and workarounds) (#3311)
  * Use CDN repos when making the worker rpms and images (#3320)
  * koji: log unsuccessful requests only once (#3314)
  * manifest/os: fix SUPPRESSED_ERROR issue reported by Coverity (#3304)
  * packer ansible: fix unregister and aarch64 cdn repos (#3322)
  * tools/appsre-ansible: don't subscribe machines used for rpmbuild (#3315)
  * worker: allow configuring number of upload threads for Azure (#3321)

Contributions from: Brian C. Lane, Diaa Sami, Sanne Raymaekers, Tomáš Hozza, schutzbot, yih

— Somewhere on the Internet, 2023-03-08


* Wed Mar 01 2023 Packit <hello@packit.dev> - 76-1
Changes with 76
----------------
  * Fix CIV_OPTIONS bug (#3297)
  * Update test suite after rebase to weldr-client-35.9 (#3296)
  * distro: assign pipeline-specific repos to package sets (#3291)
  * ignition: enable systemd firstboot condition through kargs (#3308)

Contributions from: Achilleas Koutsou, Alexander Todorov, Antonio Murdaca, Juan Abia

— Somewhere on the Internet, 2023-03-01


* Wed Feb 22 2023 Packit <hello@packit.dev> - 75-1
Changes with 75
----------------
  * Blueprint: add support for custom files and directories in `/etc` (#3281)
  * Image info: Update from manifest-db (#3278)
  * `edge-simplified-installer` allows User & Group customizations (#3285)
  * cloudapi: Add subscription option for rhc  (#3240)
  * internal/prometheus: add more buckets for job durations (#3273)
  * osbuild-worker/koji: Add logging for koji requests/responses (#3252)
  * rhel: fix conditionals for sysroot.readonly enablement (#3276)
  * test/cases: move CIV options into a variable (#3279)

Contributions from: Antonio Murdaca, Brian C. Lane, Diaa Sami, Irene Diez, Jakub Rusz, Juan Abia, Mario Cattamo, Sanne Raymaekers, Thomas Lavocat, Tomáš Hozza, Xiaofeng Wang

— Somewhere on the Internet, 2023-02-22


* Wed Feb 08 2023 Packit <hello@packit.dev> - 74-1
Changes with 74
----------------
  * Add repositories for test case generation for RHEL 9.1 (rhel-91) (#3247)
  * Adding metadata signing check (#3230)
  * Enable RHEL 8 Azure images for aarch64 (#3250)
  * Fix dracut modules for Anaconda installers in RHEL 9 and CS9 (#3253)
  * Rewrite RHEL 7 image definitions using the new framework (#3239)
  * build(deps): bump github.com/openshift-online/ocm-sdk-go from 0.1.287 to 0.1.315 (#3269)
  * cleanup leftovers, fix ignition in edge raw image and add tests (#3267)
  * distro/rhel8: don't install missing MSFT key into azure-sap-rhui (#3270)
  * internal/distro/rhel9+8/edge: add sos package (#3234)
  * osbuild: unify implementations of files input 🧹 (#3248)
  * repositories: fix rhel-90 repositories (#3263)

Contributions from: Achilleas Koutsou, Antonio Murdaca, Brian C. Lane, Diaa Sami, Irene Diez, Ondřej Budai, Sanne Raymaekers, Sarita Mahajan, Simon de Vlieger, Tomáš Hozza, Xiaofeng Wang, dependabot[bot]

— Somewhere on the Internet, 2023-02-08


* Wed Jan 25 2023 Packit <hello@packit.dev> - 73-1
Changes with 73
----------------
  * Packer: workaround missing authselect-compat-1.2.5-2.el9_1 in RHUI repos (#3237)
  * Rewrite RHEL 8 and CS8 image definitions using the new framework (#3213)
  * Schutzfile: bump osbuild commit for GA RHEL (#3214)
  * Support ignition in simplified-installer and raw-image (#3130)
  * build(deps): bump github.com/Azure/azure-sdk-for-go from 66.0.0+incompatible to 68.0.0+incompatible (#3229)
  * distro/rhel8: ensure the Azure SAP RHUI image uses appropriate config (#3233)
  * fix ostree cannot boot on fedora37 (#3217)
  * osbuild/mkdir: support new stage options and small fixes (#3226)
  * schutzbot: delete ckellner's SSH key (#3224)

Contributions from: Achilleas Koutsou, Antonio Murdaca, Gianluca Zuccarelli, Sanne Raymaekers, Tomáš Hozza, Xiaofeng Wang, dependabot[bot], yih

— Somewhere on the Internet, 2023-01-25


* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 72-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Jan 11 2023 Packit <hello@packit.dev> - 72-1
Changes with 72
----------------
  * Dashboard metrics update (#3191)
  * Enable 8.8 and 9.2 test runnners (#3134)
  * Migrate to SPDX license (#3198)
  * Schutzfile: update osbuild version to current main (v75) (#3201)
  * Update to Go 1.18 and introduce a generic ToPtr method (#3204)
  * build(deps): bump github.com/theupdateframework/go-tuf from 0.3.1 to 0.3.2 (#3205)
  * osbuild-worker: add dnf-json error reason to depsolve job error (#3174)
  * remove Fedora 35 support (#3179)
  * terraform: update to the latest definitions (#3208)
  * worker/server: log unresponsive job removal (#3206)

Contributions from: Achilleas Koutsou, Alexander Todorov, Gianluca Zuccarelli, Jakub Rusz, Miroslav Suchý, Ondřej Budai, Sanne Raymaekers, dependabot[bot]

— Somewhere on the Internet, 2023-01-11


* Wed Dec 28 2022 Packit <hello@packit.dev> - 71-1
Changes with 71
----------------
  * Enable Azure images for aarch64 (#3192)
  * Ignition blueprint config support on rhel9 (#3161)
  * Update building instructions (#3049)

Contributions from: Achilleas Koutsou, Irene Diez, Lukáš Zapletal, Sanne Raymaekers, Tomáš Hozza

— Somewhere on the Internet, 2022-12-28



* Wed Dec 14 2022 Packit <hello@packit.dev> - 70-1
Changes with 70
----------------
  * Bugfix: Add RHSM Fact (APIType) to RHEL 9 image definitions (#3160)
  * Create and add Journald stage to rhel8/9 pipeline (#3118)
  * Enable isolinux only for x86_64 (#3171)
  * Enable isolinux only for x86_64 (removed stage) (#3182)
  * Extend firewall customizations to add sources (#3055)
  * Measure 5xx errors on all requests for image-builder-composer/worker (#3147)
  * RHEL 9 & Fedora: Anaconda boot arguments (#3180)
  * RHEL 9: Do not enable user module in Anaconda Edge Installer when no users are specified (#3187)
  * RHEL 9: update edge-simplified-installer to new definitions (#3166)
  * Schutzfile: bump osbuild dependency (#3177)
  * `internal/rpmmd` cleanup 🧹 (#3159)
  * cloudapi/v2: set ostree rhsm option on image options (#3172)
  * distro/rhel9: add consumer certificates on ostree rhsm option (#3176)
  * gcp: Cross-reference to coreos-assembler code (#3163)
  * metrics: update status metrics label (#3165)
  * re-enable cs9 runner for simplified installer (#3145)
  * rhel8/9: make edge images properly sysroot.readonly=true (#3178)
  * templates/packer: increase polling delay (#3183)
  * worker: fix reporting the import error to composer (#3162)

Contributions from: Achilleas Koutsou, Antonio Murdaca, Brian C. Lane, Colin Walters, Gianluca Zuccarelli, Irene Diez, Mario Cattamo, Ondřej Budai, Sanne Raymaekers, Sayan Paul, Tomáš Hozza, Xiaofeng Wang

— Somewhere on the Internet, 2022-12-14



* Wed Nov 30 2022 Packit <hello@packit.dev> - 69-1
Changes with 69
----------------
  * Add /blueprints/change/NAME/COMMIT route and save blueprint changes in the store (#3121)
  * CloudAPI: add description for `Repository` definition (#3158)
  * Rewrite RHEL 9 and CS9 image definitions using the new framework (#3120)
  * SPEC: run the %preun commands in worker package only on removal (#3149)
  * Update snapshots to 20221115 (#3136)
  * azure-sap image (#3074)
  * ci: update Fedora 37 runners to GA (#3157)
  * cloudapi/v2: pass rhsm requirement to ostree resolve job (#3142)
  * disk: align LVM2 volumes to the extent size  (#3137)
  * image: create image-installer image type for fedora (#3077)
  * tools: silence version comparison in get_build_info() (#3150)

Contributions from: Achilleas Koutsou, Antonio Murdaca, Brian C. Lane, Christian Kellner, Ondřej Budai, Sanne Raymaekers, Sarita Mahajan, Simon de Vlieger, Tomáš Hozza, Xiaofeng Wang, fkolwa, schutzbot

— Somewhere on the Internet, 2022-11-30



* Wed Nov 16 2022 Packit <hello@packit.dev> - 68-1
Changes with 68
----------------
  * Fix iot-installer build via the cloud API (#3132)
  * Fix issues reported by Coverity (#3092)
  * Fix loading cross distro compose results (#3090)
  * RHEL-8/9 EC2 image definitions fixes (#3135)
  * Refactor the RHEL 9 SAP config and packages to be useful on other platforms (#3100)
  * ci: add my SSH keys to the CI ssh keys (#3119)
  * ci: add tags to AWS instances (#3127)
  * cloudapi/v2: expose ostree contenturl and rhsm options (#3105)
  * dbjobqueue: acquire a new connection for each listen query (#3116)
  * diff-manifests.sh: Use shared_lib for greenprint and redprint (#3133)
  * distro: SELinux should be the last stage (#3117)
  * docker-compose: remove unavailable `--dnf-json` (#3124)
  * tools/provision.sh: copy RHEL repo overrides using wildcard (#3111)

Contributions from: Brian C. Lane, Jakub Rusz, Ondřej Budai, Paul Whalen, Sanne Raymaekers, Simon de Vlieger, Thomas Lavocat, Tom Gundersen, Tomáš Hozza

— Somewhere on the Internet, 2022-11-16



* Wed Nov 02 2022 Packit <hello@packit.dev> - 67-1
Changes with 67
----------------
  * Cloud API: make `location` optional for Azure Upload Options (#3093)
  * Content url and rhsm ostree resolve (#3091)
  * Fix blueprint firewall support (#3099)
  * Ostree resolve job (#3072)
  * RHEL-8.7+/9.1+: replace RHSM config on EC2 RHUI images with `redhat-cloud-client-configuration` package (#3081)
  * Update snapshots to 20221025 (#3098)
  * build(deps): bump github.com/spf13/cobra from 1.5.0 to 1.6.1 (#3094)
  * distro: add support for RHEL 8.8 and 9.2 (#3095)
  * internal/cloudapi: add ostree options for all otree image types (#3089)
  * koji: put artifacts uploaded to koji under a second level directory (#3083)
  * schutzbot/update_github_status: fix release fast-forwarding (#3082)
  * spec: Fix ownership of the dnf-json rpmmd files (#3085)
  * tests: Update the version of azurerm terraform provider (#3075)
Contributions from: Alexander Todorov, Antonio Murdaca, Brian C. Lane, Jakub Rusz, Ondřej Budai, Sanne Raymaekers, Tomáš Hozza, dependabot[bot], schutzbot
— Somewhere on the Internet, 2022-11-02





* Wed Oct 19 2022 Packit <hello@packit.dev> - 66-1
Changes with 66
----------------
  * Build rpms on RHEL 8.8 and 9.2 (#3066)
  * Fixes for Fedora IoT image types (#3038)
  * Weldr/Cloud API: simplify GCP upload options (#3023)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.112 to 1.44.114 (#3054)
  * cloudapi: add iot-installer (#3037)
  * schutzbot/mockbuild: stop running mock as root (#3073)
Contributions from: Achilleas Koutsou, Jakub Rusz, Sanne Raymaekers, Tomáš Hozza, dependabot[bot], schutzbot
— Somewhere on the Internet, 2022-10-19





* Wed Oct 05 2022 Packit <hello@packit.dev> - 65-1
Changes with 65
----------------
  * Appsre cleanups (#3024)
  * Fix blueprint commit message (#3026)
  * Update Fedora IoT Installer definition (#3020)
  * [main] distro/rhel9: edge images default to LVM (#2861)
  * app-sre: Update AMIs to rhel-9.0 (#3019)
  * build(deps): bump cloud.google.com/go/compute from 1.9.0 to 1.10.0 (#2998)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.104 to 1.44.108 (#3034)
  * build(deps): bump github.com/google/go-cmp from 0.5.8 to 0.5.9 (#3003)
  * build(deps): bump google.golang.org/api from 0.96.0 to 0.97.0 (#3012)
  * build(deps): bump google.golang.org/api from 0.97.0 to 0.98.0 (#3027)
  * dbjobqueue: Backoff after listener error (#3036)
  * packer: add fedora 36 (#3008)
  * packer: remove Fedora 35 (#3035)
  * packit: Enable Bodhi updates for unstable Fedoras (#3017)
  * spec: bump osbuild dep to >= 65 (#3007)
  * tagging a blueprint wasn't working correctly (#3031)
  * templates/composer.yml: update splunk port for splunk cloud (#3009)
  * templates/packer: Allow token url to be set by cloud-init vars (#3010)
  * test: add CIV tool to azure.sh (#2923)
  * test: get correct CIV tag in azure.sh (#3043)
  * worker: log error details on job failure (#3025)
Contributions from: Achilleas Koutsou, Antonio Murdaca, Brian C. Lane, Diaa Sami, Irene Diez, Juan Abia, Ondřej Budai, Sanne Raymaekers, Simon Steinbeiss, Xiaofeng Wang, dependabot[bot]
— Somewhere on the Internet, 2022-10-05





* Wed Sep 21 2022 Packit <hello@packit.dev> - 64-1
Changes with 64
----------------
  * CI: Introduce x86_64 rules (#2975)
  * Cache the results of dnf-json dump and search commands (#2918)
  * Enable integration testing on aarch64 (#2895)
  * Expose Fedora IoT types in Cloud API (#3001)
  * Fix packer builds (#2969)
  * Introduce logging adapter for jobqueue (#2811)
  * New image type: Fedora IoT Raw Image (#2914)
  * RHEL-8/9: base `vhd` image on `azure-rhui` pkg sets and configuration (#2971)
  * Update snapshots to 20220906 (#2959)
  * `test/api.sh`: cleanups (#2988)
  * build(deps): bump cloud.google.com/go/compute from 1.7.0 to 1.9.0 (#2942)
  * build(deps): bump github.com/labstack/echo/v4 from 4.8.0 to 4.9.0 (#2994)
  * build(deps): bump github.com/openshift-online/ocm-sdk-go from 0.1.266 to 0.1.287 (#2985)
  * build(deps): bump google.golang.org/api from 0.94.0 to 0.96.0 (#2996)
  * build(deps): bump gopkg.in/ini.v1 from 1.66.6 to 1.67.0 (#2944)
  * distro: use storage capacity multiple constants in partition tables (#2992)
  * pkg/dbjobqueue: fix dequeue constraint error (#2963)
  * s3 upload: add an option to upload images publicly (#2897)
  * templates/dashboards: Worker tenant fixes and uncollapsed queue times (#2987)
  * templates/packer: Append distro and architecture to the ami name (#2993)
  * test: User in commit will not be supported after osbuild-composer 64 (#3000)
  * test: change CIV tag (#2958)
  * workflow: Update to golangci-lint v1.49.0 (#2973)
Contributions from: Achilleas Koutsou, Alexander Todorov, Brian C. Lane, Diaa Sami, Gianluca Zuccarelli, Jakub Rusz, Juan Abia, Lukas Zapletal, Ondřej Budai, Sanne Raymaekers, Tomas Hozza, Tomáš Hozza, Xiaofeng Wang, dependabot[bot], schutzbot, yih
— Somewhere on the Internet, 2022-09-21





* Fri Sep 16 2022 Packit <hello@packit.dev> - 62.1-1
v62.1


* Fri Sep 16 2022 Packit <hello@packit.dev> - 63.1-1
v63.1


* Wed Sep 07 2022 Packit <hello@packit.dev> - 63-1
Changes with 63
----------------
  * Add GCP guest agent config stage (#2884)
  * CI: update test execution on nightly pipelines (#2930)
  * Create multiple aws images from a single compose (#2809)
  * No rhsm facts stage on rhel or for koji composes (#2919)
  * appsre-ansible: support aarch64 machines (#2718)
  * build(deps): bump cloud.google.com/go/storage from 1.22.1 to 1.26.0 (#2934)
  * build(deps): bump github.com/Azure/go-autorest/autorest from 0.11.27 to 0.11.28 (#2937)
  * build(deps): bump github.com/containers/common from 0.48.0 to 0.49.1 (#2933)
  * build(deps): bump github.com/golang-jwt/jwt/v4 from 4.4.1 to 4.4.2 (#2938)
  * build(deps): bump github.com/gophercloud/gophercloud from 0.24.0 to 1.0.0 (#2939)
  * build(deps): bump github.com/jackc/pgx/v4 from 4.16.0 to 4.17.1 (#2926)
  * build(deps): bump github.com/labstack/echo/v4 from 4.7.2 to 4.8.0 (#2940)
  * build(deps): bump github.com/prometheus/client_golang from 1.12.1 to 1.13.0 (#2883)
  * dbjobqueue: use background context when closing listener (#2721)
  * distro/`ImageConfig`: use pointers to simple types and reflection in `InheritFrom()` (#2953)
  * rhel9: explicitly add containernetworking-plugins to edge (#2951)
  * schutzbot: Fast-forward release branch after green main run (#2922)
  * templates/packer: Increase aws timeouts for rhel-8-aarch64 (#2955)
  * test aws arm images via cloud API (#2905)
  * test/gcp: Run cleanup function at the end (#2917)
  * tests: add aarch64 rhel-9.0 runner to API tests (#2948)
  * weldr: Preload metadata at startup (#2941)
Contributions from: Achilleas Koutsou, Brian C. Lane, Diaa Sami, Jakub Rusz, Juan Abia, Lukas Zapletal, Sanne Raymaekers, Tomas Hozza, dependabot[bot], fkolwa
— Somewhere on the Internet, 2022-09-07





* Mon Aug 29 2022 Packit <hello@packit.dev> - 62-1
Changes with 62
----------------
  * cloudapi/v2: Don't add rhsm facts (#2920)
  * go.mod: update github.com/containers/image/v5 (#2925)
Contributions from: Ondřej Budai, Sanne Raymaekers
— Somewhere on the Internet, 2022-08-29





* Mon Aug 29 2022 Packit <hello@packit.dev> - 62-1
Changes with 62
----------------
  * cloudapi/v2: Don't add rhsm facts (#2920)
  * go.mod: update github.com/containers/image/v5 (#2925)
Contributions from: Ondřej Budai, Sanne Raymaekers
— Somewhere on the Internet, 2022-08-29





* Fri Aug 26 2022 Packit <hello@packit.dev> - 61-1
Changes with 61
----------------
  * Add the `rhsm.facts` stage. (#2909)
  * Disable skipped tests (#2885)
  * Support hybrid boot for edge installers (#2912)
  * worker/osbuild: use `os-release` to determine host OS (#2842)
Contributions from: Achilleas Koutsou, Juan Abia, Simon de Vlieger, Tomas Hozza, Xiaofeng Wang
— Somewhere on the Internet, 2022-08-26





* Wed Aug 24 2022 Packit <hello@packit.dev> - 60-1
Changes with 60
----------------
  * Add search command to dnf-json and use it for package searches (#2908)
  * Modify repositories/rhel-xy.json file before testing nightly compose (#2894)
  * Update terraform SHA with more aarch64 runner options (#2907)
  * [GCE images] don't install SDK and turn off GPG check on el9 (#2900)
  * distro/image-installer: remove nvmf dracut module for RHEL-9.1 (#2899)
  * distro: add oscap packages to image (#2898)
  * tests: Add comment to make it more obvious what's happening (#2888)
  * tests: Remove useless JSON file overrides (#2881)
  * update civ (#2796)
Contributions from: Alexander Todorov, Brian C. Lane, Gianluca Zuccarelli, Jakub Rusz, Juan Abia, Tomas Hozza, Xiaofeng Wang
— Somewhere on the Internet, 2022-08-24





* Wed Aug 10 2022 Packit <hello@packit.dev> - 59-1
Changes with 59
----------------
  * Allow for `/boot` to be customized (#2865)
  * CI: use only medium runners on Openstack (#2866)
  * Cloud API - support uploading to container registries (#2858)
  * Cloud API: add support for container embedding (#2877)
  * Exclude dracut-config-rescue in ec2 and qemu-guest-agent in ec2 and gce images (#2862)
  * Fix Go 1.19 issues (stable `fstab` ordering and wrong `errors.As` usages) (#2860)
  * Fix UEFI HTTP boot for RHEL 9 ISOs (#2854)
  * Use JWT for Koji tests (#2853)
  * clienterrors: Remove ellipsis operator (#2876)
  * internal/container: delete leftover dead code (#2867)
  * metrics: add `arch` label to prometheus metrics (#2845)
  * osbuild-mock-openid-provider: support `client_credentials` grant type (#2880)
  * osbuild-service-maintenance: Honor dry run config option (#2868)
  * osbuild-service-maintenance: Run vacuum analyze after each delete (#2863)
  * oscap: implement OpenSCAP build remediation (#2695)
  * templates/dashboard: filter worker dashboard on `arch` (#2847)
  * templates/dashboards: Add brew tenants (#2872)
  * templates/dashboards: Drop arch from osbuild jobtype (#2871)
  * test: Remove BIOS installation test because edge-installer supports UEFI only (#2870)
  * tests: Workaround for mkksiso options coming from newer lorax RPM (#2875)
  * worker: fix crash if no autoscale instance is defined (#2879)
Contributions from: Achilleas Koutsou, Alexander Todorov, Christian Kellner, Gianluca Zuccarelli, Jakub Rusz, Ondřej Budai, Sanne Raymaekers, Tomas Hozza, Xiaofeng Wang, Ygal Blum
— Somewhere on the Internet, 2022-08-10





* Wed Jul 27 2022 Packit <hello@packit.dev> - 58-1
Changes with 58
----------------
  * Add support for container embedding (#2814)
  * CI: drop /tmp/artifacts upload to Gitlab (#2857)
  * COMPOSER-1623: Enable Fedora 36 testing (#2782)
  * Container embedding: support accessing protected resources (#2849)
  * Embedding container in OSTree commits (#2848)
  * Filesystems test update (#2843)
  * Improvements for gen-manifests tool and Manifest-diff test (#2821)
  * Koji cloud upload fixups (#2852)
  * Regenerate fedora-35 manifests + switch RHOS-01 to non ssd (#2825)
  * Remove centos-8 repos (#2827)
  * Remove image info from all test manifests (#2855)
  * Remove koji API and the osbuild-koji job (#2822)
  * Remove osbuild1 package (#2823)
  * Support cloud upload for Koji composes (#2844)
  * Tests: Use unified diff format - easier to read (#2820)
  * Update snapshots to 20220715 (#2835)
  * blueprint: Hash all user passwords (#2834)
  * build(deps): bump actions/setup-go from 2 to 3 (#2815)
  * ci/tests: Change the way artifacts are collected (#2474)
  * image: introduce an ImageKind abstraction (#2813)
  * jobqueue: store an expiry date (#2816)
  * tag created vmare VMs (#2819)
  * templates: update dashboards to include tenant (#2756)
  * test: Install package sssd in all edge images for BZ#2088459 (#2681)
  * test: Update test for push container image to registry (#2831)
Contributions from: Achilleas Koutsou, Alexander Todorov, Brian C. Lane, Chloe Kaubisch, Christian Kellner, Gianluca Zuccarelli, Jakub Rusz, Juan Abia, Ondřej Budai, Simon de Vlieger, Tom Gundersen, Tomas Hozza, Xiaofeng Wang, dependabot[bot], schutzbot
— Somewhere on the Internet, 2022-07-27





* Wed Jul 27 2022 Packit <hello@packit.dev> - 58-1
Changes with 58
----------------
  * Add support for container embedding (#2814)
  * CI: drop /tmp/artifacts upload to Gitlab (#2857)
  * COMPOSER-1623: Enable Fedora 36 testing (#2782)
  * Container embedding: support accessing protected resources (#2849)
  * Embedding container in OSTree commits (#2848)
  * Filesystems test update (#2843)
  * Improvements for gen-manifests tool and Manifest-diff test (#2821)
  * Koji cloud upload fixups (#2852)
  * Regenerate fedora-35 manifests + switch RHOS-01 to non ssd (#2825)
  * Remove centos-8 repos (#2827)
  * Remove image info from all test manifests (#2855)
  * Remove koji API and the osbuild-koji job (#2822)
  * Remove osbuild1 package (#2823)
  * Support cloud upload for Koji composes (#2844)
  * Tests: Use unified diff format - easier to read (#2820)
  * Update snapshots to 20220715 (#2835)
  * blueprint: Hash all user passwords (#2834)
  * build(deps): bump actions/setup-go from 2 to 3 (#2815)
  * ci/tests: Change the way artifacts are collected (#2474)
  * image: introduce an ImageKind abstraction (#2813)
  * jobqueue: store an expiry date (#2816)
  * tag created vmare VMs (#2819)
  * templates: update dashboards to include tenant (#2756)
  * test: Install package sssd in all edge images for BZ#2088459 (#2681)
  * test: Update test for push container image to registry (#2831)
Contributions from: Achilleas Koutsou, Alexander Todorov, Brian C. Lane, Chloe Kaubisch, Christian Kellner, Gianluca Zuccarelli, Jakub Rusz, Juan Abia, Ondřej Budai, Simon de Vlieger, Tom Gundersen, Tomas Hozza, Xiaofeng Wang, dependabot[bot], schutzbot
— Somewhere on the Internet, 2022-07-27





* Tue Jul 19 2022 Maxwell G <gotmax@e.email> - 57-2
- Rebuild for CVE-2022-{1705,32148,30631,30633,28131,30635,30632,30630,1962} in
  golang

* Wed Jul 13 2022 Packit <hello@packit.dev> - 57-1
Changes with 57
----------------
  * Composer API - add support for service enable/disable (#2755)
  * Dockerfile: bump the shutdown period to 15 seconds (#2808)
  * Drop support for RHEL 8.3 (rhel8) and rename rhel86 to rhel8 (#2793)
  * Enable Image Builder to build GCP-compatible RHEL 9.0 images (#2771)
  * Ground work to enable cloud uploads for Koji composes (#2748)
  * Merge RHEL 8.4 distro definition into distro/rhel8 package (#2805)
  * Merge RHEL 8.5 distro definition into the distro/rhel86 package (#2787)
  * Minor test fixes (#2792)
  * build(deps): bump gopkg.in/ini.v1 from 1.66.4 to 1.66.6 (#2719)
  * containers/osbuild-composer: Sleep before shutdown to mitigate connections being reset/terminated on shutdown (#2797)
  * image-tests: skip azure-rhui test on rhel-86 (#2785)
  * jobqueue: Move jobqueue out of internal packages (#2736)
  * manifest+playground: improve developer experience (#2812)
  * manifest/os: minor refactoring to make more arguments optional (#2799)
  * manifest/os: move over bootloader packages (#2801)
  * manifest: introduce `platform`, `environment` and `workload` abstractions (#2804)
  * osbuild-image-tests: ignore LVM UUID (#2818)
  * packer: use 8.6 as a base for RHEL images (#2790)
  * packit: Enable Bodhi update feature (#2828)
  * pipeline: add Manifest abstraction (#2776)
  * set a job error when a heartbeat fails & fix koji-finalize job (#2784)
  * tag azure resources with gitlab-ci-test (#2786)
  * test/api: split into multiple files (#2789)
Contributions from: Achilleas Koutsou, Christian Kellner, Gianluca Zuccarelli, Jakub Rusz, Juan Abia, Ondřej Budai, Sanne Raymaekers, Tom Gundersen, Tomas Hozza, Ygal Blum, dependabot[bot], fkolwa, imagebuilder-bot, schutzbot
— Somewhere on the Internet, 2022-07-13





* Wed Jun 29 2022 Packit <hello@packit.dev> - 56-1
Changes with 56
----------------
  * CI: new test for checking if any manifests changed in a PR (#2749)
  * Consolidate Koji target options values meaning (#2758)
  * Fedora - Use vendor instead of rpm dependencies (#2762)
  * Remove vhd image type from RHEL 7 (#2768)
  * Support the insecure option in curl sources (#2752)
  * Switch to latest RHEL versions for testing (#2678)
  * [rhel7] add initial support (qcow2, vhd, azure-rhui) (#2705)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.4 to 1.44.43 (#2777)
  * cloudapi: get specific error from openapi (#2666)
  * cmd/osbuild-upload-gcp: fix typo in skip-import's help string (#2761)
  * dnf-json: fix depsolve error handling (#2775)
  * dnfjson: Load subscriptions when creating a new solver (#2751)
  * docker-compose: fix osbuild-worker unable load libcrypt.so.1 (#2745)
  * manifests: regenerate RHEL-8.6 qcow2 test cases (#2781)
  * pipelines: introduce declarative pipeline abstractions (#2773)
  * rpmbuild: add fedora-36 (#2770)
  * upload: initial draft for container upload (#2462)
  * worker: clean up the config and add tests (#2779)
Contributions from: Achilleas Koutsou, Alexander Todorov, Chloe Kaubisch, Christian Kellner, Jakub Rusz, Juan Abia, Ondřej Budai, Sanne Raymaekers, Tom Gundersen, Tomas Hozza, Ygal Blum, dependabot[bot], zwtop
— Somewhere on the Internet, 2022-06-29





* Wed Jun 29 2022 Packit <hello@packit.dev> - 56-1
Changes with 56
----------------
  * CI: new test for checking if any manifests changed in a PR (#2749)
  * Consolidate Koji target options values meaning (#2758)
  * Fedora - Use vendor instead of rpm dependencies (#2762)
  * Remove vhd image type from RHEL 7 (#2768)
  * Support the insecure option in curl sources (#2752)
  * Switch to latest RHEL versions for testing (#2678)
  * [rhel7] add initial support (qcow2, vhd, azure-rhui) (#2705)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.4 to 1.44.43 (#2777)
  * cloudapi: get specific error from openapi (#2666)
  * cmd/osbuild-upload-gcp: fix typo in skip-import's help string (#2761)
  * dnf-json: fix depsolve error handling (#2775)
  * dnfjson: Load subscriptions when creating a new solver (#2751)
  * docker-compose: fix osbuild-worker unable load libcrypt.so.1 (#2745)
  * manifests: regenerate RHEL-8.6 qcow2 test cases (#2781)
  * pipelines: introduce declarative pipeline abstractions (#2773)
  * rpmbuild: add fedora-36 (#2770)
  * upload: initial draft for container upload (#2462)
  * worker: clean up the config and add tests (#2779)
Contributions from: Achilleas Koutsou, Alexander Todorov, Chloe Kaubisch, Christian Kellner, Jakub Rusz, Juan Abia, Ondřej Budai, Sanne Raymaekers, Tom Gundersen, Tomas Hozza, Ygal Blum, dependabot[bot], zwtop
— Somewhere on the Internet, 2022-06-29





* Wed Jun 15 2022 Packit <hello@packit.dev> - 55-1
Changes with 55
----------------
  * Add an option to tag page blobs in Azure (#2644)
  * Add support for uploading to generic S3 service using the Composer API (#2686)
  * Blacklist amdgpu module on Azure images (#2717)
  * CI: Integrate cloud image val (#2692)
  * COMPOSER-1576: Start building rpms on 9.0 and 8.6 GA (#2716)
  * Migrate scheduled cloud cleaner to separate repo (#2728)
  * Remove UnmarshalJSON for Stage and StageOptions in osbuild packages (#2741)
  * Service maintenance: Delete results from manifest and depsolve jobs (#2707)
  * Size-based cleanup for dnf-json cache directories (#2733)
  * ci: Adjust release schedule timer (#2744)
  * cloudapi: standardize format of url strings (#2659)
  * cloudapi: use `osbuild` jobs for Koji composes (#2636)
  * dbjobqueue-tests: fix issue introduced by PR #2618 (#2730)
  * distro/rhel90: remove skx_edac, intel_cstate from denylist again (#2708)
  * dnfjson: add repository name and URL to repo-related error messages (#2734)
  * osbuild-service-maintenance:  vacuum  analyze after update (#2727)
  * osbuild-service-maintenance: Delete/update results in chunks (#2724)
  * osbuild-worker: Correct cast of dnfjson error in depsolve job (#2731)
  * packer: pin the vector version (#2725)
  * prometheus: add tenant label (#2618)
  * templates/composer: Map db secrets to maintenance container (#2722)
  * worker/osbuild: fix forgotten return when koji upload fails (#2746)
Contributions from: Achilleas Koutsou, Alexander Todorov, Chloe Kaubisch, Christian Kellner, Juan Abia, Major Hayden, Ondřej Budai, Sanne Raymaekers, Simon Steinbeiss, Tomas Hozza, Ygal Blum
— Somewhere on the Internet, 2022-06-15





* Wed Jun 01 2022 Packit <hello@packit.dev> - 54-1
Changes with 54
----------------
  * Add kube-linter check to github tests workflow (#2698)
  * Compress Azure RHUI artefacts (#2693)
  * Upload to HTTPS S3 - Support self signed certificate (#2655)
  * [rhel86/rhel90] blacklist skx_edac,intel_cstate kernel modules and enable nm-cloud-setup on azure  (#2706)
  * [rhel9] Fixes for grub2 config (ImageConfig) and azure-rhui (#2674)
  * cloudapi: Drop bucket from composer config (#2697)
  * dnf-json script and Go module rewrite (#2537)
  * templates: add Fedora prod tenant to the ACL (#2699)
  * terraform: bump to a version that does spot fleets (#2610)
  * test/old-worker: change user and package verification check (#2689)
  * test: add prominent message in test script cleanup functions (#2687)
  * tests/gcp: pick machine type from those available in the zone (#2684)
Contributions from: Achilleas Koutsou, Christian Kellner, Ondřej Budai, Sanne Raymaekers, Tomas Hozza, Ygal Blum
— Somewhere on the Internet, 2022-06-01





* Thu May 19 2022 Packit <hello@packit.dev> - 53-1
Changes with 53
----------------
  * Old worker - New composer test: Use Cloud API (#2654)
  * Post release version bump (#2670)
  * distro/rhel90: add support for azure marketplace (#2665)
  * go.mod: Update openshift-online/ocm-sdk-go (#2660)
Contributions from: Achilleas Koutsou, Christian Kellner, Sanne Raymaekers, Simon Steinbeiss
— Somewhere on the Internet, 2022-05-19





* Wed May 04 2022 Packit <hello@packit.dev> - 51-1
Changes with 51
----------------
  * Add 9.1 alias & 8.7 test repositories (#2602)
  * Devcontainer update to Fedora 36.  (#2609)
  * Don't support `gce-rhui` image type on CentOS Stream 8 (#2600)
  * New functions for resizing partitions based on directory size requirements (#2588)
  * RHEL-8.6/9.0 EC2 SAP image changes (#2574)
  * Schutzfile: Pin osbuild version to use minimal required caps (#2597)
  * Update GPG keys for all RHEL 8.x repos (#2563)
  * Use array of objects to maintain order for RPM stage inputs (#2578)
  * build(deps): bump cloud.google.com/go/cloudbuild from 1.0.0 to 1.2.0 (#2553)
  * build(deps): bump cloud.google.com/go/compute from 1.6.0 to 1.6.1 (#2587)
  * build(deps): bump github.com/Azure/azure-sdk-for-go from 63.1.0+incompatible to 63.4.0+incompatible (#2583)
  * build(deps): bump github.com/Azure/go-autorest/autorest from 0.11.25 to 0.11.27 (#2579)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.43.42 to 1.44.4 (#2606)
  * build(deps): bump github.com/google/go-cmp from 0.5.7 to 0.5.8 (#2607)
  * build(deps): bump github.com/hashicorp/go-retryablehttp from 0.7.0 to 0.7.1 (#2571)
  * build(deps): bump google.golang.org/api from 0.74.0 to 0.75.0 (#2585)
  * cloudapi/v2: Generate valid GCP image name (#2586)
  * disk: fix ensureLVM for partition tables without /boot (#2580)
  * entrypoint - add parameters for socket bind address and port (#2605)
  * image-info: dynamically detect the rpm database (#2594)
  * rhel85: automatically convert to LVM on fs customizations (#2552)
  * tools/generate-all-test-cases: add `manifests` command (#2593)
  * worker: add proxy support to worker (#2576)
  * 📦🔗📦  Introduce chain dependency solving (#2568)
Contributions from: Achilleas Koutsou, Alexander Todorov, Christian Kellner, Ondřej Budai, Sanne Raymaekers, Simon de Vlieger, Tomas Hozza, Ygal Blum, dependabot[bot]
— Somewhere on the Internet, 2022-05-04





* Thu Apr 28 2022 Packit <hello@packit.dev> - 46.3-1
CHANGES WITH 46.3:
----------------
 * disk: fix ensureLVM for partition tables without /boot (#2580)
Contributions from: Achilleas Koutsou, Christian Kellner
— Liberec, 2022-04-28




* Wed Apr 20 2022 Packit <hello@packit.dev> - 50-1
Changes with 50
----------------
  * COMPOSER-1401: Add tests for blueprints without explicit definition for / (#2412)
  * Empty manifest check for osbuild jobs (#2520)
  * Generic S3 test - retry creating the alias in case the service is not yet up (#2543)
  * Introduce Google GCE image type (RHEL, CentOS Stream) and support importing to GCP on premise (#2155)
  * Pin fedora repositories in Schutzfile + override mock templates with rpmrepo snapshots (#2508)
  * Support uploading to any S3 service via the WELDR API (#2471)
  * Worker dependency errors (#2505)
  * build(deps): bump cloud.google.com/go/storage from 1.18.2 to 1.22.0 (#2565)
  * build(deps): bump github.com/Azure/azure-sdk-for-go from 57.4.0+incompatible to 63.1.0+incompatible (#2532)
  * build(deps): bump github.com/Azure/go-autorest/autorest/azure/auth from 0.5.8 to 0.5.11 (#2534)
  * build(deps): bump github.com/BurntSushi/toml from 0.4.1 to 1.1.0 (#2525)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.42.25 to 1.43.38 (#2548)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.43.38 to 1.43.42 (#2566)
  * build(deps): bump github.com/google/go-cmp from 0.5.6 to 0.5.7 (#2526)
  * build(deps): bump github.com/gophercloud/gophercloud from 0.22.0 to 0.24.0 (#2536)
  * build(deps): bump github.com/jackc/pgtype from 1.8.1 to 1.10.0 (#2524)
  * build(deps): bump github.com/jackc/pgx/v4 from 4.13.0 to 4.15.0 (#2530)
  * build(deps): bump github.com/labstack/echo/v4 from 4.6.1 to 4.7.2 (#2531)
  * build(deps): bump github.com/prometheus/client_golang from 1.12.0 to 1.12.1 (#2549)
  * build(deps): bump github.com/spf13/cobra from 0.0.3 to 1.4.0 (#2560)
  * build(deps): bump github.com/stretchr/testify from 1.7.0 to 1.7.1 (#2535)
  * build(deps): bump github.com/vmware/govmomi from 0.26.1 to 0.27.4 (#2554)
  * build(deps): bump gopkg.in/ini.v1 from 1.63.0 to 1.66.4 (#2292)
  * cloudapi: specify min_size type (#2319)
  * gitlab: fix nightly testing (#2569)
  * lib: upgrade prometheus client to 1.12 (#2528)
  * osbuild2: QEMU stage implementation enhancement and code de-duplication (#2521)
  * templates/packer: Rely on instance metadata to set region (#2562)
  * workflows/trigger-gitlab: run Gitlab CI in new image-builder project (#2547)
Contributions from: Alexander Todorov, Chloe Kaubisch, Christian Kellner, Gianluca Zuccarelli, Jakub Rusz, Ondřej Budai, Sanne Raymaekers, Thomas Lavocat, Tomas Hozza, Ygal Blum, dependabot[bot]
— Somewhere on the Internet, 2022-04-20





* Wed Apr 06 2022 Packit <hello@packit.dev> - 49-1
Changes with 49
----------------
  * Add Xiaofeng to notifications for nightly pipeline (#2486)
  * Add `cloud-init` to VMDK image and test it in VSphere (#2459)
  * Centos pinning + Schutzfile update (#2494)
  * Create users at install time for image and edge installers (#2375)
  * Dependency joberrors (#2477)
  * Fix excessive logging and monitoring (#2497)
  * Minor CI changes (#2468)
  * RHEL (all): Create users at install time for image and edge installers (#2516)
  * RHEL-90: use XBOOTLDR partition GUID for `/boot` (#2473)
  * Regression tests split (#2498)
  * `rhel{86,90}`: set default grub boot entry to `saved` (#2418)
  * build(deps): bump actions/checkout from 2.4.0 to 3 (#2394)
  * build(deps): bump actions/github-script from 5 to 6 (#2463)
  * build(deps): bump actions/setup-go from 2.1.5 to 3 (#2395)
  * build(deps): bump github.com/Azure/go-autorest/autorest from 0.11.21 to 0.11.25 (#2507)
  * ci: re-enabled Installer test on centos-stream-9 (#2514)
  * cloudapi: improve gpgkey handling & enable edge-commit on Fedora (#2479)
  * cloudapi: prevent dangling goroutines after the server is terminated (#2518)
  * cmd: add `osbuild-package-sets` for printing package sets of an image (#2484)
  * container: fix liveness probe (#2482)
  * gitlab: split integration tests (#2488)
  * koji: fix retries when uploading chunks (#2466)
  * osbuild2: honor GPG key setting for rpm inputs (#2432)
  * repositories: update key for RHEL 9.0 (#2509)
  * rhel8/9: fix path to fdo diun root certificates (#2434)
  * templates/composer: Add prod service accounts owner (#2478)
  * templates/composer: Drop unused variables (#2481)
  * templates/composer: Remove unused acl claims (#2483)
  * test/ostree-simplified-installer: destroy VM fixup (#2487)
  * test: Add retries on ubi8 image and greenboot package downloading (#2493)
  * test: Clean up and improve ostree-simplified-installer.sh (#2485)
  * test: Enable CS9 test for ostree-rebase and ostree (#2515)
  * test: use `T.TempDir` to create temporary test directory (#2417)
  * tests: Run SonarQube analysis only on main branch (#2489)
  * tools/define-compose-url: change url back to nightly (#2513)
Contributions from: Achilleas Koutsou, Alexander Todorov, Antonio Murdaca, Christian Kellner, Diaa Sami, Eng Zer Jun, Gianluca Zuccarelli, Jakub Rusz, Ondřej Budai, Sanne Raymaekers, Tomas Hozza, Xiaofeng Wang, dependabot[bot], yih
— Somewhere on the Internet, 2022-04-06





* Sat Apr 02 2022 Packit <hello@packit.dev> - 46.2-1
CHANGES WITH 46.2:
----------------
 * repositories: update key for RHEL 9.0  (#2509)
Contributions from: Ondřej Budai
— Liberec, 2022-04-02




* Fri Apr 01 2022 Packit <hello@packit.dev> - 46.1-1
CHANGES WITH 46.1:
----------------
  * internal/distro/rhel{86,90}: drop console kargs from raw image deployment (#2377)
  * RHEL-90: use XBOOTLDR partition GUID for /boot (#2473)
  * Create users at install time for image and edge installers (#2375)
  * rhel{86,90}: set default grub boot entry to saved (#2418)
  * rhel8/9: fix path to fdo diun root certificates (#2434)
  * nightly: update GPG key in prepare-rhel-internal & fix some tests (#2389)
  * mockbuild: use public EPEL-9 (#2364)
  * api.sh: encrypt the DB dump artifact (#2472)
  * image tests: update GPG keys used for RHEL-9.0 repos (#2390)
  * gitlab: split integration tests (#2488)
  * test/cases/simpl installer: bump to use fdo 0.4.0 (#2380)
  * test/ostree-simplified-installer: destroy VM fixup (#2487)
  * test/image-tests: temporarily skip azure_rhui image testing (#2402)
  * test: Clean up and improve ostree-simplified-installer.sh (#2485)
  * test: Add retries on ubi8 image and greenboot package downloading (#2493)
  * tests/upgrade: update gpg key (#2467)
  * test: add tests purpose (#2346)
  * test/api.sh cleanup (#2444)
  * Centos pinning + Schutzfile update (#2494)
  * Update snapshots to 20220301 (#2376)
  * ci: run ci_details.sh in before_script (#2403)
  * ci: Minor CI changes (#2468)
  * ci: skip CI for draft and WIP PRs (#2286)
  * ci: modify Gitlab CI trigger (#2416)
  * ci: Fix Gitlab CI trigger + revert debug (#2457)
Contributions from: Achilleas Koutsou, Alexander Todorov, Antonio Murdaca, Christian Kellner,
                    Jakub Rusz, Juan Abia, Ondřej Budai, Tomas Hozza, Xiaofeng Wang
— Vöcklabruck, 2022-04-01




* Wed Mar 23 2022 Packit Service <user-cont-team+packit-service@redhat.com> - 48-1
CHANGES WITH 48:
----------------
  * create-tag: Fix bash typo (#2476)
  * image tests: update GPG keys used for RHEL-9.0 repos (#2390)
  * create-tag: Fix upstream release schedule (#2475)
  * api.sh: encrypt the DB dump artifact (#2472)
  * Enable scheduled upstream releases (#2458)
  * dbjobqueue: fix race condition (#2456)
  * container: graceful shutdown (#2447)
  * tests/upgrade: update gpg key (#2467)
  * deploy: work around a podman bug in CS8  (#2464)
  * templates/composer: Add stage service accounts owner (#2465)
  * workflows: Fix Gitlab CI trigger + revert debug (#2457)
  * Client creds grant worker client (#2433)
  * workflows: debug Gitlab CI trigger (#2441)
  * osbuild-worker: Log unexpected dnf-json errors (#2454)
  * packer: use unique name tag for Fedora workers (#2429)
  * `test/api.sh` cleanup (#2444)
  * internal/distro/rhel{86,90}: drop console kargs from raw image deploy… (#2377)
  * Dashboards - Minor fixes (#2435)
  * github workflows: modify Gitlab CI trigger (#2416)
  * ci: run ci_details.sh in before_script (#2403)
  * packer: fix the secret ID variable in get_koji_creds.sh (#2431)
  * packer: make subscribing optional (#2430)
  * packer: make all credentials optional and add support for koji credentials (#2426)
  * dnf-json: use the default connection timeout (#2428)
  * Pass repo name to `dnf-json` and use it in `dnf-json` (#2427)
  * dbjobqueue: reduce the number of needed connections (#2393)
  * cmd/osbuild-worker: dnf-json returns MarkingErrors (plural) (#2361)
  * use app-sre packer image (#2409)
  * packer: Build Fedora 35 x86_64 and aarch64 images (#2423)
  * github: fix job names and IDs for the tests workflow (#2422)
  * weldr: Run on unsupported distros (#2399)
  * koji: reduce excessive logging by retryablehttp (#2397)
  * test: add tests purpose (#2346)
  * Packit: build SRPMs in Copr (#2414)
  * mockbuild: use public EPEL-9 (#2364)
  * cmd/osbuild-worker: Pass bucket config to job implementation (#2411)
Contributions from: Achilleas Koutsou, Antonio Murdaca, Diaa Sami, Feng Huang, Gianluca Zuccarelli, Jakub Rusz, Juan Abia, Laura Barcziova, Ondřej Budai, Sanne Raymaekers, Simon Steinbeiss, Tom Gundersen, Tomas Hozza, kingsleyzissou
— Somewhere on the Internet, 2022-03-23





* Wed Mar 09 2022 Packit Service <user-cont-team+packit-service@redhat.com> - 47-1
CHANGES WITH 47:
----------------
  * cloudapi/v2: add error object to ImageStatus (#2298)
  * cmd/osbuild-worker: Configure s3 bucket on the worker itself (#2404)
  * 🍏  Make CI green again (#2401)
  * 🍏  test/image-tests: temporarily skip azure_rhui image testing (#2402)
  * templates/composer: give access to Fedora org (#2405)
  * dnf-json codestyle cleanup (#2391)
  * cloudapi: add support for multi-tenancy (#2344)
  * ci: skip CI for draft and WIP PRs  (#2286)
  * nightly: update GPG key in prepare-rhel-internal & fix some tests (#2389)
  * templates/packer: Remove -u flag from creds mapping script (#2396)
  * Implement HTTP retries for koji jobs (#2352)
  * `rhel86` various fixes for the `azure-rhui` image (#2387)
  * Update snapshots to 20220301 (#2376)
  * schutzbot: update terraform SHA (#2385)
  * test/cases/simpl installer: bump to use fdo 0.4.0 (#2380)
  * schutzbot: fix jrusz ssh key (#2384)
  * schutzbot: add jrusz ssh-key (#2383)
  * Small cloudapi cleanups (#2379)
  * cmd/osbuild-service-maintenance: Log aws error (#2315)
  * templates/composer: Parametrize bucket name (#2372)
Contributions from: Achilleas Koutsou, Antonio Murdaca, Christian Kellner, Diaa Sami, Gianluca Zuccarelli, Jakub Rusz, Ondřej Budai, Sanne Raymaekers, Tomas Hozza, Xiaofeng Wang, ondrejbudai, schutzbot
— Cork, 2022-03-09




* Mon Feb 28 2022 Packit Service <user-cont-team+packit-service@redhat.com> - 46-1
CHANGES WITH 46:
----------------
  * Simplified installer: add support for encrypted raw images (#2295)
  * rhel86: automatically convert to LVM on fs customizations (#2373)
  * RHEL9.0: convert layout to LVM on filesystem customisations (#2354)
  * Update snapshots to 20220227 (#2370)
  * Add Azure Marketplace images (#2358)
  * devcontainer: adapt to composer (#2306)
  * Update snapshots to 20220226 (#2368)
  * RHEL 8.6: Add lvm2 to build root (#2367)
  * schutzbot: keep runners alive when users are logged on (#2328)
  * Adjust filesystem tests (#2362)
  * Set selinux to permissive mode for installers (#2359)
  * RHEL-90: use C.UTF-8 for images that only have glibc-minimal-langpack (#2351)
  * test: Add work around for bug bz#2057769 (#2366)
  * templates: Add production worker account to acl (#2365)
  * tests/libvirt: add some regression tests (#2294)
  * test/manifest/image-installer: fix conflicting merge (#2360)
  * rhel86/90: change isolevel of image-installer to 3 (#2325)
  * Update snapshots to 20220222 (#2343)
  * simplified installer (8/9): support FDO (#1884)
  * Image installer on aarch64 (#2355)
  * FS minimum size (#2353)
  * templates/composer: Verify against mass sso and rh sso (#2349)
  * RHEL 9.0: Fix customisation of Kernel command line options (#2342)
  * internal/cloudapi: Allow bp.Customizations being nil (#2340)
  * Support specifying OSTree Parent and URL for creating upgrade commits (#2201)
  * COMPOSER-1343: Revert "tests: Conditionally enable osbuild-dnf-json-tests" (#2338)
  * Update team_ssh_keys.txt (#2333)
  * templates/worker: fix depsolve error rate (#2337)
  * worker/osbuild-koji: fix double-reporting of osbuild-koji job status (#2327)
  * Revert "mockbuild: temporarily pin RHEL 9 compose to an older one" (#2332)
  * test: Remove "ansible-galaxy collection install" (#2334)
  * Schutzfile: Pin centos-9's osbuild commit (#2339)
  * LUKS & LVM support and file system refactoring (#2141)
  * internal/cloudapi: Log error in manifest job (#2336)
  * internal/cloud: Allow aws creds from defaults (#2291)
  * worker: use default transport instead of "blank" one (#2316)
  * cloudapi: expose filesystem customizations (#2285)
Contributions from: Achilleas Koutsou, Alexander Todorov, Antonio Murdaca, Chloe Kaubisch, Christian Kellner, Djebran Lezzoum, Gianluca Zuccarelli, He Yi, Jakub Rusz, Ondřej Budai, Sanne Raymaekers, Tom Gundersen, Tomas Hozza, Xiaofeng Wang
— Vöcklabruck, 2022-03-01




* Fri Feb 18 2022 Packit Service <user-cont-team+packit-service@redhat.com> - 45-1
CHANGES WITH 45:
----------------
  * mockbuild: temporarily pin RHEL 9 compose to an older one (#2321)
  * Add CentOS Stream 9 support (#2142)
  * Cancel waiting compose (#2237)
  * tests: Use human readable size for mountpoint (#2304)
  * worker: Properly log successful image builds (#2313)
  * Deduplicate some code in distro definitions (#2314)
  * tests/upgrade: gather more logs (#2299)
  * packer: make the worker image smaller (#2311)
  * ci/nightly: report composer NVR in slack (#2317)
  * fsjobqueue: refactor to allow dequeuing by multiple criteria (#2307)
  * github: fetch more PRs when triggering gitlab (#2312)
  * Update greenboot packaging names (#2196)
  * github: split checks into 3 jobs (#2308)
  * cmd/osbuild-service-maintenance: GCP deletes by image name (#2293)
  * Extend information gathered by `image-info` (#2303)
  * Fix problem with undo creating empty blueprint (#2207)
  * Support associating repositories to package sets (#2265)
  * Use the latest RPMRepo snapshot for RHEL-9.0 image tests (#2279)
  * tests: update IDs in Openstack image boot test (#2263)
  * Pre-define an ostree remote for RFE raw images (including created via simplified installer) (#2284)
Contributions from: Achilleas Koutsou, Alexander Todorov, Brian C. Lane, Christian Kellner, Jakub Rusz, Ondřej Budai, Peter Robinson, Sanne Raymaekers, Simon Steinbeiss, Thomas Lavocat, Tomas Hozza, Xiaofeng Wang
— Liberec, 2022-02-18




* Fri Feb 11 2022 Packit Service <user-cont-team+packit-service@redhat.com> - 44-1
CHANGES WITH 44:
----------------
  * Relax TCP timeouts for koji connections (#2282)
  * cloudapi/v2: add support for aws-*-rhui image types (#2281)
  * Add oracle-oci.md under image-types/rhel8 (#2283)
  * Appsre packer 85 (#2274)
  * Add missing F34 and F35 image test cases (#2276)
  * templates/dashboard: worker metric queries (#2277)
  * distro: add an alias for RHEL 8.7 (#2270)
  * metrics: change job metrics namespace (#2272)
  * Revert "templates: Add dnf-json template" (#2273)
  * Sonarqube fix + Schutzfile repo rename (#2261)
  * Drop F33 support and add F34/F35 image tests (#2264)
  * github: fix gitlab trigger (#2271)
  * Skip CI for draft PRs or WIP label (#2238)
  * service-maintenance: Skip db cleanup (#2252)
  * templates/dashboards: worker error metrics (#2267)
  * build(deps): bump cloud.google.com/go/cloudbuild from 0.2.0 to 1.0.0 (#2153)
  * update testing doc with cloud cleaner info (#2256)
  * RHEL-90: Remove deprecated `crashkernel=auto` option (#2262)
  * templates: Add dnf-json template (#2259)
  * Worker error validation (#2260)
  * Prepare CI to build -tests RPM for downstream testing from source (#2093)
  * worker: fix error status codes (#2258)
  * Workers error metrics (#2247)
  * gitlab-ci: make every stage interruptible (#2248)
  * internal/cloud/gcp: use `pkg.go.dev/cloud.google.com/go` for Compute Engine (#2162)
  * EC2: Disable password based authentication (#2235)
  * Dnf json (#2194)
  * worker/api: align error handler with cloudapi (#2152)
  * cloupapi/v2: add koji support (#2214)
  * RHEL 9.0: Drop IA32 (#2219)
  * jwt: support multiple key providers (#2239)
  * Mock OpenID: add token type, expires in and scope fields (#2240)
  * distro/rhel86: fix ec2 boot partition for arm64 (#2228)
  * Extend scheduled cloud cleaner to vmware (#2200)
  * Kojiapi: fix error check in koji job (#2236)
  * osbuild-worker: change error handling for OCI upload (#2234)
  * distro/rhel90: special case root user for ssh keys (#2220)
  * OCI support (#2031)
  * distro/rhel90: no uuids in dos partition table (#2233)
  * Worker errors backwards compatibility (#2192)
  * repo runner (#2216)
  * test/koji: remove the koji-cli patch (#2223)
  * packit: re-enable builds for s390x architecture (#2246)
Contributions from: Achilleas Koutsou, Alexander Todorov, Antonio
                    Murdaca, Christian Kellner, Diaa Sami, Gianluca
                    Zuccarelli, Jakub Rusz, Juan Abia, Ondřej Budai,
                    Pavel Raiskup, Roy Golan, Sanne Raymaekers,
                    Tom Gundersen, Tomas Hozza, Thomas Lavocat
— Grenoble, 2022-02-11




* Wed Jan 26 2022 Packit Service <user-cont-team+packit-service@redhat.com> - 43-1
CHANGES WITH 43:
----------------
  * templates/dashboards: Fixed grafana uids (#2202)
  * CI: Updates to ensure smoother running (#2198)
  * templates/packer: Make cdn host check less sensitive (#2199)
  * templates/packer: Correct priority for worker rpms (#2195)
  * tools/appsre-ansible: Don't use /tmp for rpmbuilds (#2186)
Contributions from: Alexander Todorov, Jakub Rusz, Thomas Lavocat,
                    Sanne Raymaekers
— Grenoble, 2022-01-26




* Wed Jan 12 2022 Packit Service <user-cont-team+packit-service@redhat.com> - 42-1
CHANGES WITH 42:
----------------
  * RHEL-86/90: refactoring of `osPipeline` and its variants (#2139)
  * api/cloud: drop v1 API (#2163)
  * weldr: return an error if host distro wasn't found in distro registry (#2158)
  * dnf json cache cleaner (#2119)
  * Update terraform SHA (#2157)
  * build(deps): bump actions/setup-go from 2.1.4 to 2.1.5 (#2156)
Contributions from: Achilleas Koutsou, Jakub Rusz, Juan Abia,
                    Ondřej Budai, Thomas Lavocat, Tomas Hozza,
                    Sanne Raymaekers
— Grenoble, 2022-01-12




* Wed Dec 22 2021 Packit Service <user-cont-team+packit-service@redhat.com> - 41-1
CHANGES WITH 41:
----------------
  * build(deps): bump actions/checkout from 2.3.4 to 2.4.0 (#2007)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.40.49 to 1.42.25 (#2150)
  * osbuild2: fix typo in tar stage option value (#2151)
  * osbuild2: support 'format' and 'root-node' Tar stage options (#2146)
  * Tools: add 'no-image-info' option to image test case requests (#2143)
  * generate-all-test-cases: use `make scratch` for building RPMs (#2138)
  * osbuild-auth-tests: add a build constraint also to certificates.go (#2097)
  * dbjobqueue: fix FinishJob not returning an error if already finished (#2133)
  * osbuild2: Expand dnf_config stage (#2113)
  * test: make test more resilient (#2132)
  * worker: Treat a non echo.HTTPError like a regular error (#2140)
  * osbuild2: ensure that empty sysconfig options members are omitted (#2134)
  * Add support for new osbuild stages needed for GCE image (#2126)
  * tools: use image_type_tags in repos used for image test cases (#2135)
  * composer: Only set queue and artifact dir for fsqueue (#2095)
  * cloudapi: improve logging for errors (#2088)
  * Tracing: measure IO during each job (#2106)
  * Tests: trim dependencies for test generation (#2128)
  * metrics: add additional buckets (#2130)
  * distro/depsolve/cloudapi: Add 3rd-party repository support. (#2101)
  * templates: add worker dashboard (#2127)
  * dnf json as a service (#2062)
  * Extend scheduled cloud cleaner to GCP (#2115)
  * openstack: use rhos-01 (#2120)
  * RHEL-9.0: unify the default partitioning scheme used by all non-EDGE images (#2019)
  * ci: CC QE in notification message (#2118)
  * enable gosec tool (#2073)
  * release-action: Send notification to our Slack channel (#2117)
Contributions from: Alexander Todorov, Diaa Sami, Djebran Lezzoum, Gianluca Zuccarelli, Juan Abia, Ondřej Budai, Sanne Raymaekers, Simon Steinbeiss, Thomas Lavocat, Tomas Hozza, dependabot[bot]
— Liberec, 2021-12-22




* Thu Dec 09 2021 Packit Service <user-cont-team+packit-service@redhat.com> - 40-1
CHANGES WITH 40:
----------------
  * Regression test fixes (#2109)
  * store: set RHSM when initialising SourceConfig with a repo (#2105)
  * spec: build all binaries with PIE (#2102)
  * Job metrics (#2080)
  * tests: Fix several permission and koji failures (#2099)
  * templates: Max concurrent requests is required for the maintenance job (#2107)
  * templates: CronJob is part of the batch/v1 api (#2104)
  * generate-all-test-cases: add `--build-rpms` option (#2098)
  * templates: Add maintenance cronjob (#2100)
  * Use PackIt for building RPMs in COPR for PRs and commits to `main` (#2094)
  * Image Builder Composer - Grafana dashboard Updates (#2089)
  * Cloud API: Support more image types as S3 objects (#2081)
  * osbuild-service-maintenance: Clean up expired images (#2074)
  * cloudapi/v2: No ObjectReference in request bodies (#2042)
  * distro/rhel90: enable edge-simplified-installer image type (#2015)
  * ci: Install gssapi/gssapi.h for Coverity Scan (#2087)
  * 8.5 runners (#2079)
  * RHEL-9.0: Install TuneD by default and stop using `@core` package group (#2084)
  * Build a worker AMI using Schutzbot (#2068)
  * osbuild2: update cloud-init stage with new options (#2051)
  * tests: Small updates to docs (#2011)
  * api/koji: fix /compose/log route (#2078)
  * ci: make some jobs interruptible (#2061)
  * tests/nightly: Re-enable satellite regression test on nightly composes (#2052)
  * test: cloud cleaner aws s3 (#2005)
  * rpmmd: Reload subscriptions (#2067)
  * Two minor logging improvements (#2063)
  * terraform: update to use the new instance type (#2065)
  * spec: add epoch to nevra only if it's set (#2060)
Contributions from: Achilleas Koutsou, Alex Njaastad, Alexander Todorov, Chloe Kaubisch, Gianluca Zuccarelli, Jakub Rusz, Juan Abia, Martin Sehnoutka, Ondřej Budai, Sanne Raymaekers, Tomas Hozza
— Liberec, 2021-12-09




* Wed Nov 24 2021 Packit Service <user-cont-team+packit-service@redhat.com> - 39-1
CHANGES WITH 39:
----------------
  * RHEL-9.0: install and enable TuneD by default on all EC2 images (#2050)
  * Improve contributing.md (#2043)
  * osbuild2: selinux stage - introduce force_autorelabel option (#2033)
  * internal: cleanup dracut modules and default kargs (#2045)
  * Namespaced composer metrics (#2037)
  * cloudapi/v2: Add support for edge-container (#2035)
  * template: bump postgres max conns to 20 (#2044)
  * templates: bump max postgres connections to 10 (#2040)
  * osbuild2: update rhsm stage (#2014)
  * internal: mandate installation device for the simplified installer (#1755)
  * distro/rhel86: use the new coreos-installer-dracut (#1752)
  * Switch api tests to v2 & manifest job in api v2 (#2026)
  * cloudapi/v1: Adapt metadata handler to osbuild2 results (#2028)
  * osbuild: check if result objects are nil in Write() (#2022)
  * distro/rhel90*: minor code cleanup (#2004)
  * osbuild2: support 'install' command in the modprobe stage and rework data validation (#1983)
  * Use RHUI-4 for RHEL-9 EC2 image test cases (#1977)
  * Logging improvements (#1989)
  * worker: Correct servers in openapi spec (#1988)
  * job/osbuild: skip the job if manifest generation failed (#2018)
  * spec: bump osbuild version to 41 (#2012)
  * composer: Add metrics endpoint to auth excludes again (#2013)
  * Use V2 results internally (#1754)
  * worker: Introduce manifest-id-only job (#1999)
  * jobqueue: add the ability to dequeue by ID (#1997)
  * Multiple new stages (#2006)
  * containers: mock oauth container (#2003)
  * osbuild2: new stage sshd config (#1992)
Contributions from: Achilleas Koutsou, Alexander Todorov, Antonio Murdaca, Diaa Sami, Gianluca Zuccarelli, Jakub Rusz, Juan Abia, Martin Sehnoutka, Ondřej Budai, Sanne Raymaekers, Simon Steinbeiss, Tomas Hozza, Xiaofeng Wang, diaasami, sanne, yih
— Berlin, 2021-11-24































* Wed Nov 10 2021 Packit Service <user-cont-team+packit-service@redhat.com> - 38-1
- Revert "templates: Add prometheus scrape annotations to composer-api" (Sanne Raymaekers)
- templates: Add prometheus scrape annotations to composer-api (sanne)
- distroregistry: disable CentOS Stream 9 (Achilleas Koutsou)
- test/cases: rm ostree-ng-og.sh (Achilleas Koutsou)
- distro/rhel90: remove all mentions of obsolete firmware packages (Achilleas Koutsou)
- test/data: update manifests for edge-container images (Achilleas Koutsou)
- distro/rhel90: make nginx log and lib directories world writable (Achilleas Koutsou)
- distro/rhel90: disable edge-simplified-installer image type (Achilleas Koutsou)
- Schutzfile: remove osbuild version pin for RHEL 9.0 (Achilleas Koutsou)
- tools: update distro-arch-imagetype-map for RHEL 9.0 types (Achilleas Koutsou)
- tools: update RHEL 9.0 repos for test case generators (Achilleas Koutsou)
- test/data: update RHEL 9.0 and beta manifests (Achilleas Koutsou)
- test/ostree-simplified: variable string fixes (Achilleas Koutsou)
- distro/rhel90: update unit tests (Achilleas Koutsou)
- rhel90: drop -ga suffix and alias from beta (Achilleas Koutsou)
- test/api: ssh key fixes for RHEL 9.0 (Achilleas Koutsou)
- test/cases: support weldr-client output structure (Achilleas Koutsou)
- CI: test new edge types on RHEL 9.0 (Achilleas Koutsou)
- test/ostree: install python3 instead of specific version (Achilleas Koutsou)
- mockbuild: change RHEL 9 template to use latest non-beta repos (Achilleas Koutsou)
- test/cases: add RHEL 9.0 and CentOS 9 cases to test scripts (Achilleas Koutsou)
- CI: enable tests for RHEL 9.0 (Achilleas Koutsou)
- schutzbot: update terraform sha (Achilleas Koutsou)
- test: update test manifests for rhel-90-ga (Achilleas Koutsou)
- tools: add centos-9 to distro-arch-imagetype-map (Achilleas Koutsou)
- tools: copy rhel-90 distro-arch-imagetype-map to -beta and -ga (Achilleas Koutsou)
- distro/rhel90: update to match 8.6 and add centos-9 alias (Achilleas Koutsou)
- distro/rhel86: remove genisoimage (Achilleas Koutsou)
- distro/rhel86: single osbuild import (Achilleas Koutsou)
- test/data: copy rhel-90 test manifests to -ga and -beta (Achilleas Koutsou)
- test: add repositories for rhel-90-beta and -ga (Achilleas Koutsou)
- distroregistry: add rhel-90-ga to registry (Achilleas Koutsou)
- distro: copy rhel90beta to rhel90 (Achilleas Koutsou)
- composer: Add worker openapi spec endpoint to auth excludes (sanne)
- CI: Journal-log is accessible and encrypted (Thomas Lavocat)
- spec: Only run worker preun if systemd is running (sanne)
- gitlab-ci: Remove RHEL9.0-beta runners (Martin Sehnoutka)
- schutzbot: double quote jq argument to prevent shellcheck failures (Martin Sehnoutka)
- distribution: worker dnf-json & cache dir (Gianluca Zuccarelli)
- cloudapi/v2: 5xx error metrics (Gianluca Zuccarelli)
- internal/blueprint: allow filesystem size specified with units (Martin Sehnoutka)
- internal/blueprint: introduce custom fs customization parser (Martin Sehnoutka)
- internal/blueprint: introduce new test for parsing blueprints (Martin Sehnoutka)
- internal/common: introduce function to convert data sizes (Martin Sehnoutka)
- prepare_rhel_internal: configure s3cmd explicitly (Jakub Rusz)
- templates: add latency metrics to dashboard (Gianluca Zuccarelli)
- Let schutzbot do the post-release version bump (Simon Steinbeiss)
- Post release version bump (Simon Steinbeiss)
- cloudapi: record error metrics (Gianluca Zuccarelli)
- prometheus: add middleware function (Gianluca Zuccarelli)
- prometheus: compose latency metric (Gianluca Zuccarelli)
- prometheus: update metrics (Chloe Kaubisch)
- templates: fix liveness/readiness check url (Ondřej Budai)
- templates: add s3 bucket name (Ondřej Budai)
- templates: update dashboard config map (Gianluca Zuccarelli)
- templates: add grafana dashboard (Gianluca Zuccarelli)
- build(deps): bump github.com/openshift-online/ocm-sdk-go (dependabot[bot])
- templates: hook up simple probes and default limits (Tom Gundersen)
- templates: add service account (Tom Gundersen)

* Wed Oct 27 2021 Packit Service <user-cont-team+packit-service@redhat.com> - 37-1
- Bump version numbers ahead of release (Simon Steinbeiss)
- Switch to simple upstream releases (Simon Steinbeiss)
- distro/rhel86: special case root user for ssh keys (Christian Kellner)
- Revert "Revert "cloudapi/v1: Move depsolving to workers"" (Tom Gundersen)
- templates: image-builder-ci access to composer (Tom Gundersen)
- ci: remove 8.5 nightly testing (Ondřej Budai)
- composer: add json log formatting (Diaa Sami)
- test: timestamp messages in test scripts (Achilleas Koutsou)
- Add news item for updated CentOS Stream 8 definitions (Achilleas Koutsou)
- test/api: SSH_USER=ec2-user for centos on AWS (Achilleas Koutsou)
- test/cases: add centos-8 as support to test scripts (Achilleas Koutsou)
- test/ansible: install greenboot-failing-unit from public source (Achilleas Koutsou)
- CI: enable OSTree tests on CentOS 8 (Achilleas Koutsou)
- test/data: regenerate manifests for CentOS 8 (Achilleas Koutsou)
- distro/rhel86: skip RHSM config stage for non-RHEL (Achilleas Koutsou)
- distro/rhel86: distro private method isRHEL() (Achilleas Koutsou)
- test/data/repositories: update cs8 rpmrepo snapshot (Achilleas Koutsou)
- tools: add all supported image types for centos-8 (Achilleas Koutsou)
- tools/test-case-generators: fix typo in imagetype-map (Achilleas Koutsou)
- distro/rhel86: add distro specific package set (Achilleas Koutsou)
- test: add RHEL 8.6 image installer test manifest (Achilleas Koutsou)
- distro/rhel86: add CentOS Stream 8 as alias to RHEL 8.6 (Achilleas Koutsou)
- distro/rhel86: remove redundant rhel-86 alias (Achilleas Koutsou)
- spec: dnf-json conflicts with old composer (Achilleas Koutsou)
- ostree: change the URL for OC client temporarily (Ondřej Budai)
- test/aws: remove a no longer needed key from an instance (Ondřej Budai)
- ci: pin a specific RHEL 9.0b compose (Ondřej Budai)
- ci: rotate secret names (Ondřej Budai)
- mockbuild: explicitly configure s3cmd (Ondřej Budai)
- mockbuild: remove subscriptions (Ondřej Budai)
- .gitlab-ci: Don't save the journal as an artifact (sanne)
- jobqueue: Better logging (Diaa Sami)
- templates: Claims based on user_ids (sanne)
- worker: Configurable timeout for RequestJob (sanne)
- build(deps): bump cloud.google.com/go/storage from 1.16.1 to 1.18.1 (dependabot[bot])
- build(deps): bump github.com/labstack/echo/v4 from 4.5.0 to 4.6.1 (dependabot[bot])
- build(deps): bump github.com/gophercloud/gophercloud (dependabot[bot])
- worker: Separate goroutine for depsolve jobs (sanne)
- cloudapi/v2: Plural path section when querying a collection (sanne)
- cloudapi/v2: Do not require auth for /openapi or /errors (sanne)
- worker: Configure AWS credentials in the worker (Thomas Lavocat)
- cloudapi/v2: ensure only one image per a compose in the API spec (Ondřej Budai)
- cloudapi/v2: clean up targets (Ondřej Budai)
- cloudapi/v2: move multi-image compose check to the beginning (Ondřej Budai)

* Wed Oct 13 2021 Packit Service <user-cont-team+packit-service@redhat.com> - 36-1
- 36 (Achilleas Koutsou)
- Revert "cloudapi/v1: Move depsolving to workers" (Sanne Raymaekers)
- worker: Prefix https always (sanne)
- cloudapi/v1: Move depsolving to workers (sanne)
- cloudapi/v2: fix newV2Server() call in test (Achilleas Koutsou)
- templates: Name service ports (sanne)
- SPEC: Exclude `armv7hl` architecture (Tomas Hozza)
- distro/rhel90 -> distro/rhel90beta: rename package (Achilleas Koutsou)
- distro/rhel90: rename to rhel-90-beta and alias base name (Achilleas Koutsou)
- spec: Split dnf-json into a subpackage (sanne)
- cloudapi/v2: Use worker to depsolve (Ondřej Budai)
- worker: Add a depsolve job type (Tom Gundersen)
- packit: Push downstream instead of creating PR (Simon Steinbeiss)
- templates: Name services after endpoints (sanne)
- worker: Make BasePath configurable (sanne)
- cloudapi/v2: Listen on /api/image-builder-composer/v2 (sanne)
- test/ostree: remove --ip-range from podman network (Achilleas Koutsou)
- RHEL-8.6: add support for official EC2 SAP image (Tomas Hozza)
- tools/provision: set up nightly repos for RHEL 8.6 (Achilleas Koutsou)
- test/cases: add support for RHEL 8.6 to test scripts (Achilleas Koutsou)
- schutzbot: pin osbuild to current main for 8.6 (Achilleas Koutsou)
- schutzbot: update terraform sha (Achilleas Koutsou)
- news: add entry about RHEL 8.6 (Achilleas Koutsou)
- test: add RHEL 8.6 test manifests (Achilleas Koutsou)
- test: add rpmrepo snapshots for RHEL 8.6 (Achilleas Koutsou)
- ci: run all tests on RHEL 8.6 (Achilleas Koutsou)
- test/data/repositories: add test repos for rhel-86 (Achilleas Koutsou)
- distro/rhel85: remove rhel86 alias (Achilleas Koutsou)
- distro/rhel86: copy all definitions from rhel85 (Achilleas Koutsou)
- cloudapi/v2: Configurable aws bucket (sanne)
- cloudapi/v2: Replace upload types with image types (sanne)
- Tests/RHEL-9.0: add EC2 SAP image test (Tomas Hozza)
- Tests/RHEL-9.0: add repos needed for EC2 SAP image tests (Tomas Hozza)
- RHEL-9.0: add EC2 SAP image definition. (Tomas Hozza)
- Tests/RHEL-9.0: add EC2 and EC2 HA image tests (Tomas Hozza)
- Tests/RHEL-9.0: add repos needed for EC2 and EC2 HA image tests (Tomas Hozza)
- Image tests: skip rpm-ostree-1-autovar.conf tmpfiles.d config on Fedora (Tomas Hozza)
- composer: Don't dump sensitive fields from config (sanne)
- tests: Update image_tests (Jakub Rusz)
- templates: Duplicate value in composer config (sanne)
- templates: Port names should be less than 15 characters (sanne)
- templates: Make sure ports are unquoted (sanne)
- cloudapi/v1: Return status created in compose handler (sanne)
- worker: Use Recover middleware to handle panics (Diaa Sami)
- worker: Improve logging (Diaa Sami)
- Regenerate affected image test cases (Tomas Hozza)
- generate-all-test-cases: allow specifying additional DNF repos (Tomas Hozza)
- image-info: ensure that directory is analysed as read-only (Tomas Hozza)
- tests: enable koji.sh test on RHEL-9 (Jakub Rusz)
- tests/ci: enable vmware.sh and cross-distro.sh on rhel-9 (Jakub Rusz)
- README: Add a link to our developer guide (Simon Steinbeiss)
- templates: Composer OSD template (sanne)
- internal/rpmmd: log repository files loaded during composer startup (Martin Sehnoutka)
- dnf-json: expire metadata by default (Tom Gundersen)
- schutzbot: Clean up non-default storage accounts (sanne)
- main: IsNotExist() is no longer a valid check (Achilleas Koutsou)
- config: update NonExisting test to check for default (Achilleas Koutsou)
- config: don't fail LoadConfig if file doesn't exist (Achilleas Koutsou)
- Test: regenerate all image test cases (Tomas Hozza)
- Image tests: use RPMRepo with released RHEL-8.4 content (Tomas Hozza)
- image-info: fix undefined variable in analyse_directory() (Tomas Hozza)
- image-info: sort partitions list in the report. (Tomas Hozza)
- image-info: use subprocess_check_output() in read_selinux_ctx_mismatch() (Tomas Hozza)
- image-info: check not installed documentation (Tomas Hozza)
- image-info: read content of /etc/resolv.conf (Tomas Hozza)
- image-info: read sysctl.d config files from multiple paths (Tomas Hozza)
- image-info: read security limits config files from multiple paths (Tomas Hozza)
- image-info: read tmpfiles.d config files from multiple paths (Tomas Hozza)
- image-info: read systemd service unit drop-ins from multiple paths (Tomas Hozza)
- image-info: read cloud-init configs from multiple paths (Tomas Hozza)
- image-info: read systemd-logind configs from multiple paths (Tomas Hozza)
- image-info: read dracut configs from multiple paths (Tomas Hozza)
- image-info: read modprobe configs from multiple paths (Tomas Hozza)
- composer: More configuration of how composer is served (sanne)

* Sat Oct 02 2021 Packit Service <user-cont-team+packit-service@redhat.com> - 35-1
- 35 (Simon Steinbeiss)
- gitleaks: add allow list for test passwords and keys (Achilleas Koutsou)
- mockbuild: use download.devel of download.eng.bos (Ondřej Budai)
- ci: install ansible-core instead of ansible for EL9 (Ondřej Budai)
- dnf-json: disable zchunk (Ondřej Budai)
- composer: improve logging (Diaa Sami)
- cloudapi: Add extra logging & improve existing (Diaa Sami)
- cloudapi: use Logrus as default logger in Echo (Diaa Sami)
- logging: add logrus dependency (Diaa Sami)
- ci: don't run nightly pipeline on ga releases (Jakub Rusz)
- distro/rhel90: use qcow2 compat 1.1 for qcows (Ondřej Budai)
- tools: Push ubi container to quay.io/app-sre/composer (sanne)
- blueprints: change minsize from int to uint64 (Gianluca Zuccarelli)
- test/regression: Adapt to new rhel-84-ga runners (sanne)
- schutzbot: Also build container on branch pushes (sanne)
- schutzbot: pin osbuild to >=37 on all distros (Ondřej Budai)
- spec: bump osbuild depedendency to 37 (Ondřej Budai)
- distro/rhel85: set bootloader to none for edge (Christian Kellner)
- osbuild2: add bootloader option to ostree.config (Christian Kellner)
- osbuild2: small doc fix for ostree.config (Christian Kellner)
- build(deps): bump github.com/labstack/echo/v4 from 4.5.0 to 4.6.0 (dependabot[bot])
- build(deps): bump github.com/aws/aws-sdk-go from 1.40.46 to 1.40.49 (dependabot[bot])
- workers: Backwards compatible api.openshift.com spec compliance (sanne)
- Disable regression-composer-works-behind-satellite.sh, Refs #1834 (Alexander Todorov)
- test/ostree: use 8.4 when testing on 8.4 (Ondřej Budai)
- ci: add workaround for missing redhat.repo in EC2 (Ondřej Budai)
- schutzfile: remove rhel-8.3 (Ondřej Budai)
- test/koji: always build the latest RHEL (Ondřej Budai)
- mockbuild: use REPO_BUCKET when defining the base URL (Ondřej Budai)
- test: use hyphen in DISTRO_CODE instead of underscore (Ondřej Budai)
- test: move env variables into set-env-variables helper (Ondřej Budai)
- test/koji: remove the workaround for rhel-8 (Ondřej Budai)
- test/api: don't source os-release again (Ondřej Budai)
- test: use cdn repos for 8.3 and 8.4 (Ondřej Budai)
- mockbuild: reuse nightly repos from redhat.repo (Ondřej Budai)
- ci: assume subscribed machines (Ondřej Budai)
- terraform: update (Ondřej Budai)
- build(deps): bump github.com/Azure/azure-sdk-for-go (dependabot[bot])
- distribution: Use After=network.target instead of multi-user (Martin Sehnoutka)
- internal/common: introduce git revision and rpm version (Martin Sehnoutka)
- test/ostree: support weldr-client output structure (Achilleas Koutsou)
- test/data: update test manifests for RHEL 9.0 edge (Achilleas Koutsou)
- distro/rhel90: explicitly enable greenboot services for edge (Achilleas Koutsou)
- distro/rhel90: add gnome-kiosk to installer package set (Achilleas Koutsou)
- tools/provision: install community.general ansible collection (Achilleas Koutsou)
- test/ostree: remove debug callback from ansible calls (Achilleas Koutsou)
- test/ostree: install python3 instead of specific version (Achilleas Koutsou)
- distro/rhel90: remove unavailable packages from edge-installer (Achilleas Koutsou)
- ci: enable ostree tests on RHEL 9.0-beta (Achilleas Koutsou)
- NEWS: Drop title line (Simon Steinbeiss)
- cloudapi: use Recover middleware to handle panics (Diaa Sami)
- HACKING: fix container command (Gianluca Zuccarelli)
- containers: worker client base url protocol (Gianluca Zuccarelli)
- containers: update composer log level flag (Gianluca Zuccarelli)
- Regenerate relevant image test cases (Tomas Hozza)
- distro/rhel90: re-include nss-altfiles for edge (Christian Kellner)
- generate-test-cases: drop `--with-customizations` option (Tomas Hozza)
- format-request-map.json: remove redundant overrides (Tomas Hozza)
- generate-test-cases: don't leak "supported_arches" to compose request (Tomas Hozza)
- tools: improve deploy-openstack script (Diaa Sami)
- weldr: deleting an unknown source should return an error (Brian C. Lane)
- Update distro-arch-imagetype-map.json (Tomas Hozza)
- test: update image test case generation part of README (Tomas Hozza)
- generate-all-test-cases: add option to keep created workdir on runner (Tomas Hozza)
- generate-all-test-cases: report results when Runner finishes (Tomas Hozza)
- generate-all-test-cases: support using existing remote hosts (Tomas Hozza)
- generate-all-test-cases: remove '--keep-image-info' option (Tomas Hozza)
- generate-all-test-cases: move current generator method to 'qemu' command (Tomas Hozza)
- generate-all-test-cases: fix log level in multiprocessing processes (Tomas Hozza)
- generate-all-test-cases: don't use virtfs to copy data from/to the VM (Tomas Hozza)
- generate-all-test-cases: don't use paramiko for SSH (Tomas Hozza)
- generate-all-test-cases: use SSH keys instead of password for VMs (Tomas Hozza)
- generate-all-test-cases: don't use cloud-init to install RPMs (Tomas Hozza)
- generate-all-test-cases: fix generating of cloud-init cdrom on MacOS (Tomas Hozza)
- generate-all-test-cases: separate generic parts of BaseRunner (Tomas Hozza)
- build(deps): bump github.com/aws/aws-sdk-go from 1.40.43 to 1.40.46 (dependabot[bot])
- generate-test-cases: check `supported_arches` from format-request-map.json (Tomas Hozza)
- schutzbot: Update terraform sha (sanne)
- Drop RELEASING.md and point to dev guide (Simon Steinbeiss)
- build(deps): bump github.com/Azure/go-autorest/autorest (dependabot[bot])
- build(deps): bump github.com/aws/aws-sdk-go from 1.40.38 to 1.40.43 (dependabot[bot])
- build(deps): bump github.com/openshift-online/ocm-sdk-go (dependabot[bot])

* Wed Aug 11 2021 Ondřej Budai <ondrej@budai.cz> - 31-1
- New upstream release

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 30-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Mon Jun 14 2021 Ondřej Budai <ondrej@budai.cz> - 30-1
- New upstream release

* Fri Mar 05 2021 Martin Sehnoutka <msehnout@redhat.com> - 29-1
- New upstream release

* Tue Mar 02 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 28-2
- Rebuilt for updated systemd-rpm-macros
  See https://pagure.io/fesco/issue/2583.

* Sat Feb 20 2021 Martin Sehnoutka <msehnout@redhat.com> - 28-1
- New upstream release

* Thu Feb 04 2021 Ondrej Budai <obudai@redhat.com> - 27-1
- New upstream release

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 26-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Thu Dec 17 2020 Ondrej Budai <obudai@redhat.com> - 26-2
- Fix the compatibility with a new golang-github-azure-storage-blob 0.12

* Thu Dec 17 2020 Ondrej Budai <obudai@redhat.com> - 26-1
- New upstream release

* Thu Nov 19 2020 Ondrej Budai <obudai@redhat.com> - 25-1
- New upstream release

* Thu Nov 12 2020 Ondrej Budai <obudai@redhat.com> - 24-1
- New upstream release

* Fri Nov 06 2020 Ondrej Budai <obudai@redhat.com> - 23-1
- New upstream release

* Fri Oct 16 2020 Ondrej Budai <obudai@redhat.com> - 22-1
- New upstream release

* Sun Aug 23 2020 Tom Gundersen <teg@jklm.no> - 20-1
- New upstream release

* Tue Aug 11 2020 Tom Gundersen <teg@jklm.no> - 19-1
- New upstream release

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 18-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jul 22 2020 Ondrej Budai <obudai@redhat.com> - 18-1
- New upstream release

* Wed Jul 08 2020 Ondrej Budai <obudai@redhat.com> - 17-1
- New upstream release

* Mon Jun 29 2020 Ondrej Budai <obudai@redhat.com> - 16-1
- New upstream release

* Fri Jun 12 2020 Ondrej Budai <obudai@redhat.com> - 15-1
- New upstream release

* Thu Jun 04 2020 Ondrej Budai <obudai@redhat.com> - 14-1
- New upstream release

* Fri May 29 2020 Ondrej Budai <obudai@redhat.com> - 13-2
- Add missing osbuild-ostree dependency

* Thu May 28 2020 Ondrej Budai <obudai@redhat.com> - 13-1
- New upstream release

* Thu May 14 2020 Ondrej Budai <obudai@redhat.com> - 12-1
- New upstream release

* Wed Apr 29 2020 Ondrej Budai <obudai@redhat.com> - 11-1
- New upstream release

* Wed Apr 15 2020 Ondrej Budai <obudai@redhat.com> - 10-1
- New upstream release

* Wed Apr 01 2020 Ondrej Budai <obudai@redhat.com> - 9-1
- New upstream release

* Mon Mar 23 2020 Ondrej Budai <obudai@redhat.com> - 8-1
- Initial package (renamed from golang-github-osbuild-composer)
